@@ -7,13 +7,15 @@ Module that contains base functionality for Qt widgets
 
 from __future__ import print_function, division, absolute_import
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
+from Qt.QtCore import Qt, Property, Signal, Property
+from Qt.QtWidgets import QApplication, QSizePolicy, QWidget, QFrame, QScrollArea, QWhatsThis
 
-from tpDcc.libs.qt.core import qtutils, mixin, theme
+from tpDcc.libs.resources.core import theme
+from tpDcc.libs.qt.core import qtutils, contexts as qt_contexts
+from tpDcc.libs.qt.widgets import layouts
 
 
-@mixin.theme_mixin
+@theme.mixin
 class BaseWidget(QWidget, object):
     """
     Base class for all QWidgets based items
@@ -80,11 +82,7 @@ class BaseWidget(QWidget, object):
         :return: QLayout
         """
 
-        layout = QVBoxLayout()
-        layout.setContentsMargins(2, 2, 2, 2)
-        layout.setSpacing(2)
-        layout.setAlignment(Qt.AlignTop)
-        return layout
+        return layouts.VerticalLayout(spacing=2, margins=(2, 2, 2, 2))
 
     def ui(self):
         """
@@ -94,7 +92,7 @@ class BaseWidget(QWidget, object):
 
         self.main_layout = self.get_main_layout()
         if self._use_scrollbar:
-            layout = QVBoxLayout()
+            layout = layouts.VerticalLayout(spacing=0, margins=(0, 0, 0, 0))
             self.setLayout(layout)
             central_widget = QWidget()
             central_widget.setSizePolicy(QSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding))
@@ -176,16 +174,41 @@ class BaseWidget(QWidget, object):
         return self
 
 
+@theme.mixin
 class BaseFrame(QFrame, object):
     mouseReleased = Signal(object)
 
     def __init__(self, *args, **kwargs):
         super(BaseFrame, self).__init__(*args, **kwargs)
 
+        self.ui()
+        self.setup_signals()
+
     def mouseReleaseEvent(self, event):
         self.mouseReleased.emit(event)
         return super(BaseFrame, self).mouseReleaseEvent(event)
 
+    def get_main_layout(self):
+        """
+        Function that generates the main layout used by the widget
+        Override if necessary on new widgets
+        :return: QLayout
+        """
+
+        return layouts.VerticalLayout(spacing=2, margins=(2, 2, 2, 2))
+
+    def ui(self):
+        """
+        Function that sets up the ui of the widget
+        Override it on new widgets (but always call super)
+        """
+
+        self.main_layout = self.get_main_layout()
+        self.setLayout(self.main_layout)
+
+    def setup_signals(self):
+        pass
+
 
 class ContainerWidget(QWidget, object):
     """
@@ -195,9 +218,7 @@ class ContainerWidget(QWidget, object):
     def __init__(self, parent=None):
         super(ContainerWidget, self).__init__(parent)
 
-        layout = QHBoxLayout(self)
-        layout.setContentsMargins(0, 0, 0, 0)
-        layout.setSpacing(0)
+        layout = layouts.HorizontalLayout(spacing=0, margins=(0, 0, 0, 0))
         self.setLayout(layout)
 
         self.containedWidget = None
@@ -235,8 +256,16 @@ class DirectoryWidget(BaseWidget, object):
         self._last_directory = None
         super(DirectoryWidget, self).__init__(parent=parent, **kwargs)
 
-    @property
-    def directory(self):
+    def _get_directory(self):
+        return self._directory
+
+    def _set_directory(self, directory):
+        with qt_contexts.block_signals(self):
+            self.set_directory(directory)
+
+    directory = Property(str, _get_directory, _set_directory)
+
+    def get_directory(self):
         return self._directory
 
     def set_directory(self, directory):
