@@ -7,10 +7,7 @@ Module that contains constants for tpQtLib
 
 from __future__ import print_function, division, absolute_import
 
-__author__ = "Tomas Poveda"
-__license__ = "MIT"
-__maintainer__ = "Tomas Poveda"
-__email__ = "tpovedatd@gmail.com"
+LIB_ID = 'tpDcc-libs-qt'
 
 # DPI
 DEFAULT_DPI = 96
