@@ -7,18 +7,13 @@ Module that contains widgets to to drag PySide windows and dialogs
 
 from __future__ import print_function, division, absolute_import
 
-__author__ = "Tomas Poveda"
-__license__ = "MIT"
-__maintainer__ = "Tomas Poveda"
-__email__ = "tpoveda@cgart3d.com"
+from Qt.QtCore import Qt, Signal, QPoint, QSize, QTimer
+from Qt.QtWidgets import QApplication, QSizePolicy, QWidget, QFrame, QSpacerItem, QPushButton
+from Qt.QtGui import QColor, QPainter
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
-from Qt.QtGui import *
-
-import tpDcc
+from tpDcc.managers import resources
 from tpDcc.libs.qt.core import qtutils
-from tpDcc.libs.qt.widgets import label
+from tpDcc.libs.qt.widgets import layouts, label
 
 
 class WindowDragger(QFrame, object):
@@ -28,6 +23,8 @@ class WindowDragger(QFrame, object):
 
     DEFAULT_LOGO_ICON_SIZE = 22
 
+    doubleClicked = Signal()
+
     def __init__(self, window=None, on_close=None):
         super(WindowDragger, self).__init__(window)
 
@@ -45,71 +42,9 @@ class WindowDragger(QFrame, object):
 
         self.ui()
 
-    def ui(self):
-
-        palette = self.palette()
-        palette.setColor(self.backgroundRole(), QColor(35, 35, 35))
-        self.setPalette(palette)
-
-        self.setFixedHeight(qtutils.dpi_scale(40))
-        self.setAutoFillBackground(True)
-
-        main_layout = QHBoxLayout()
-        main_layout.setContentsMargins(15, 0, 15, 0)
-        main_layout.setSpacing(5)
-        self.setLayout(main_layout)
-
-        self._logo_button = self._setup_logo_button()
-        self._title_text = label.ClippedLabel(text=self._window.windowTitle())
-        self._title_text.setObjectName('WindowDraggerLabel')
-        self._contents_layout = QHBoxLayout()
-        self._corner_contents_layout = QHBoxLayout()
-
-        main_layout.addWidget(self._logo_button)
-        main_layout.addWidget(self._title_text)
-        main_layout.addItem(QSpacerItem(25, 0, QSizePolicy.Fixed, QSizePolicy.Fixed))
-        main_layout.addLayout(self._contents_layout)
-        main_layout.addLayout(self._corner_contents_layout)
-
-        buttons_widget = QWidget()
-        self.buttons_layout = QHBoxLayout()
-        self.buttons_layout.setAlignment(Qt.AlignRight)
-        self.buttons_layout.setContentsMargins(0, 0, 0, 0)
-        self.buttons_layout.setSpacing(0)
-        buttons_widget.setLayout(self.buttons_layout)
-        main_layout.addWidget(buttons_widget)
-
-        self._button_minimized = QPushButton()
-        self._button_minimized.setIconSize(QSize(25, 25))
-        # self._button_minimized.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
-        self._button_minimized.setIcon(tpDcc.ResourcesMgr().icon('minimize', theme='window'))
-        self._button_minimized.setStyleSheet('QWidget {background-color: rgba(255, 255, 255, 0); border:0px;}')
-        self._button_maximized = QPushButton()
-        self._button_maximized.setIcon(tpDcc.ResourcesMgr().icon('maximize', theme='window'))
-        # self._button_maximized.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
-        self._button_maximized.setStyleSheet('QWidget {background-color: rgba(255, 255, 255, 0); border:0px;}')
-        self._button_maximized.setIconSize(QSize(25, 25))
-        self._button_restored = QPushButton()
-        # self._button_restored.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
-        self._button_restored.setVisible(False)
-        self._button_restored.setIcon(tpDcc.ResourcesMgr().icon('restore', theme='window'))
-        self._button_restored.setStyleSheet('QWidget {background-color: rgba(255, 255, 255, 0); border:0px;}')
-        self._button_restored.setIconSize(QSize(25, 25))
-        self._button_closed = QPushButton()
-        # button_closed.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
-        self._button_closed.setIcon(tpDcc.ResourcesMgr().icon('close', theme='window'))
-        self._button_closed.setStyleSheet('QWidget {background-color: rgba(255, 255, 255, 0); border:0px;}')
-        self._button_closed.setIconSize(QSize(25, 25))
-
-        self.buttons_layout.addWidget(self._button_minimized)
-        self.buttons_layout.addWidget(self._button_maximized)
-        self.buttons_layout.addWidget(self._button_restored)
-        self.buttons_layout.addWidget(self._button_closed)
-
-        self._button_maximized.clicked.connect(self._on_maximize_window)
-        self._button_minimized.clicked.connect(self._on_minimize_window)
-        self._button_restored.clicked.connect(self._on_restore_window)
-        self._button_closed.clicked.connect(self._on_close_window)
+    # =================================================================================================================
+    # PROPERTIES
+    # =================================================================================================================
 
     @property
     def contents_layout(self):
@@ -119,6 +54,10 @@ class WindowDragger(QFrame, object):
     def corner_contents_layout(self):
         return self._corner_contents_layout
 
+    # =================================================================================================================
+    # OVERRIDES
+    # =================================================================================================================
+
     def mousePressEvent(self, event):
         if event.button() == Qt.LeftButton and self._dragging_enabled:
             self._mouse_press_pos = event.globalPos()
@@ -143,6 +82,8 @@ class WindowDragger(QFrame, object):
             self._on_maximize_window()
         else:
             self._on_restore_window()
+        super(WindowDragger, self).mouseDoubleClickEvent(event)
+        self.doubleClicked.emit()
 
     def mouseReleaseEvent(self, event):
         if self._mouse_press_pos is not None:
@@ -153,18 +94,80 @@ class WindowDragger(QFrame, object):
                 self._mouse_press_pos = None
         super(WindowDragger, self).mouseReleaseEvent(event)
 
-    def set_icon(self, icon, highlight_color=None):
+    # =================================================================================================================
+    # BASE
+    # =================================================================================================================
+
+    def ui(self):
+        self.setFixedHeight(qtutils.dpi_scale(40))
+
+        main_layout = layouts.HorizontalLayout(spacing=5, margins=(15, 0, 15, 0))
+        self.setLayout(main_layout)
+
+        self._logo_button = self._setup_logo_button()
+        self._title_text = label.ClippedLabel(text=self._window.windowTitle())
+        self._title_text.setObjectName('WindowDraggerLabel')
+        self._contents_layout = layouts.HorizontalLayout()
+        self._corner_contents_layout = layouts.HorizontalLayout()
+
+        main_layout.addWidget(self._logo_button)
+        main_layout.addWidget(self._title_text)
+        main_layout.addItem(QSpacerItem(25, 0, QSizePolicy.Fixed, QSizePolicy.Fixed))
+        main_layout.addLayout(self._contents_layout)
+        main_layout.addLayout(self._corner_contents_layout)
+
+        buttons_widget = QWidget()
+        self.buttons_layout = layouts.HorizontalLayout(spacing=0, margins=(0, 0, 0, 0))
+        self.buttons_layout.setAlignment(Qt.AlignRight)
+        buttons_widget.setLayout(self.buttons_layout)
+        main_layout.addWidget(buttons_widget)
+
+        self._button_minimized = QPushButton()
+        self._button_minimized.setIconSize(QSize(25, 25))
+        # self._button_minimized.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
+        self._button_minimized.setIcon(resources.icon('minimize', theme='window'))
+        self._button_minimized.setStyleSheet('QWidget {background-color: rgba(255, 255, 255, 0); border:0px;}')
+        self._button_maximized = QPushButton()
+        self._button_maximized.setIcon(resources.icon('maximize', theme='window'))
+        # self._button_maximized.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
+        self._button_maximized.setStyleSheet('QWidget {background-color: rgba(255, 255, 255, 0); border:0px;}')
+        self._button_maximized.setIconSize(QSize(25, 25))
+        self._button_restored = QPushButton()
+        # self._button_restored.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
+        self._button_restored.setVisible(False)
+        self._button_restored.setIcon(resources.icon('restore', theme='window'))
+        self._button_restored.setStyleSheet('QWidget {background-color: rgba(255, 255, 255, 0); border:0px;}')
+        self._button_restored.setIconSize(QSize(25, 25))
+        self._button_closed = QPushButton()
+        # button_closed.setSizePolicy(QSizePolicy(QSizePolicy.Fixed, QSizePolicy.Fixed))
+        self._button_closed.setIcon(resources.icon('close', theme='window'))
+        self._button_closed.setStyleSheet('QWidget {background-color: rgba(255, 255, 255, 0); border:0px;}')
+        self._button_closed.setIconSize(QSize(25, 25))
+
+        self.buttons_layout.addWidget(self._button_minimized)
+        self.buttons_layout.addWidget(self._button_maximized)
+        self.buttons_layout.addWidget(self._button_restored)
+        self.buttons_layout.addWidget(self._button_closed)
+
+        self._button_maximized.clicked.connect(self._on_maximize_window)
+        self._button_minimized.clicked.connect(self._on_minimize_window)
+        self._button_restored.clicked.connect(self._on_restore_window)
+        self._button_closed.clicked.connect(self._on_close_window)
+
+    def set_icon(self, icon=None, highlight=False):
         """
         Sets the icon of the window dragger
         :param icon: QIcon
+        :param highlight: bool
         """
 
+        icon = icon or self._window.windowIcon()
         if not icon or icon.isNull():
-            return
+            icon = resources.icon('tpDcc')
 
         size = self.DEFAULT_LOGO_ICON_SIZE
 
-        if highlight_color is not None:
+        if highlight:
             self._logo_button.set_icon(
                 [icon], colors=[None], tint_composition=QPainter.CompositionMode_Plus, size=size,
                 icon_scaling=[1], color_offset=0, grayscale=True)
@@ -231,16 +234,16 @@ class WindowDragger(QFrame, object):
 
         self._logo_button.setVisible(False)
 
-    def set_window_buttons_state(self, state):
+    def set_window_buttons_state(self, state, show_close_button=False):
         """
         Sets the state of the dragger buttons
-        :param enabled: bool
-        :param visible: bool
+        :param state: bool
+        :param show_close_button: bool
         """
 
         self._lock_window_operations = not state
-        self._button_closed.setEnabled(state)
-        self._button_closed.setVisible(state)
+        self._button_closed.setEnabled(state or show_close_button)
+        self._button_closed.setVisible(state or show_close_button)
 
         if self._maximize_enabled:
             self._button_maximized.setEnabled(state)
@@ -270,7 +273,11 @@ class WindowDragger(QFrame, object):
         :param frameless: bool
         """
 
-        tool_inst = tpDcc.ToolsMgr().get_tool_by_plugin_instance(self._window)
+        from tpDcc.managers import tools
+
+        tool_inst = tools.ToolsManager().get_tool_by_plugin_instance(self._window)
+        if not tool_inst:
+            return
 
         offset = QPoint()
 
@@ -352,9 +359,11 @@ class WindowDragger(QFrame, object):
         Internal callback function that is called when the user clicks on close button
         """
 
+        from tpDcc.managers import tools
+
         closed = False
         if hasattr(self._window, 'WindowId'):
-            closed = tpDcc.ToolsMgr().close_tool(self._window.WindowId, force=False)
+            closed = tools.ToolsManager().close_tool(self._window.WindowId, force=False)
 
         if not closed:
             if hasattr(self._window, 'docked'):
