@@ -18,13 +18,12 @@ try:
 except ImportError:
     import urllib
 
-from Qt.QtCore import *
-from Qt.QtGui import *
+from Qt.QtCore import Qt, Signal, QByteArray, QRunnable, QObject, QTimer
+from Qt.QtGui import QImage, QPixmap, QBitmap, QIcon, QColor, QPainter
 
-from tpDcc.libs import qt
 from tpDcc.libs.python import python, path as path_utils
 
-LOGGER = logging.getLogger()
+LOGGER = logging.getLogger('tpDcc-libs-qt')
 
 ImageFormats = {
     QImage.Format_Mono: 'L',                            # Mono
@@ -249,7 +248,7 @@ class ImageWorker(QRunnable, object):
                 image = QImage(str(self._path))
                 self.signals.triggered.emit(image)
         except Exception as e:
-            qt.logger.error('Cannot load thumbnail image!')
+            LOGGER.error('Cannot load thumbnail image!')
 
 
 class ImageSequence(QObject, object):
@@ -273,12 +272,18 @@ class ImageSequence(QObject, object):
 
     def set_path(self, path):
         """
-        Set as singal frame image sequence
+        Sets s single frame image sequence
         :param path: str
         """
 
-        self._frame = 0
-        self._frames = [path]
+        if not path:
+            return
+
+        if os.path.isfile(path):
+            self._frame = 0
+            self._frames = [path]
+        elif os.path.isdir(path):
+            self.set_dirname(path)
 
     def dirname(self):
         """
@@ -313,6 +318,17 @@ class ImageSequence(QObject, object):
             self._frames = [dirname + '/' + filename for filename in os.listdir(dirname)]
             natural_sort_items(self._frames)
 
+    def first_frame(self):
+        """
+        Returns the path of the first frame of the sequence
+        :return: str
+        """
+
+        if not self._frames:
+            return ''
+
+        return self._frames[0]
+
     def start(self):
         """
         Starts the image sequence
@@ -460,7 +476,11 @@ def image_to_base64(image_path):
 
     if os.path.isfile(image_path):
         with open(image_path, 'rb') as image_file:
-            return base64.b64encode(image_file.read())
+            base64_data = base64.b64encode(image_file.read())
+            if python.is_python2():
+                return base64_data
+            else:
+                return base64_data.decode("utf-8")
 
 
 def base64_to_image(base64_string, image_format='PNG'):
@@ -471,10 +491,12 @@ def base64_to_image(base64_string, image_format='PNG'):
     :return: QImage
     """
 
-    if isinstance(base64_string, basestring):
+    try:
         ba = QByteArray.fromBase64(base64_string)
         image = QImage.fromData(ba, image_format)
         return image
+    except Exception:
+        return None
 
 
 def base64_to_bitmap(base64_string, bitmap_format='PNG'):
@@ -485,11 +507,10 @@ def base64_to_bitmap(base64_string, bitmap_format='PNG'):
     :return: QBitmap
     """
 
-    if isinstance(base64_string, basestring):
-        image = base64_to_image(base64_string, bitmap_format)
-        if image is not None:
-            bitmap = QBitmap.fromImage(image)
-            return bitmap
+    image = base64_to_image(base64_string, bitmap_format)
+    if image is not None:
+        bitmap = QBitmap.fromImage(image)
+        return bitmap
 
 
 def base64_to_icon(base64_string, icon_format='PNG'):
@@ -500,8 +521,7 @@ def base64_to_icon(base64_string, icon_format='PNG'):
     :return: QIcon
     """
 
-    if isinstance(base64_string, basestring):
-        bitmap = base64_to_bitmap(base64_string, icon_format)
-        if bitmap is not None:
-            icon = QIcon(bitmap)
-            return icon
+    bitmap = base64_to_bitmap(base64_string, icon_format)
+    if bitmap is not None:
+        icon = QIcon(bitmap)
+        return icon
