@@ -7,14 +7,15 @@ Module that contains extended functionality for QMenus
 
 from __future__ import print_function, division, absolute_import
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
+from Qt.QtCore import Qt, Signal
+from Qt.QtWidgets import QLineEdit, QMenu, QActionGroup, QAction, QWidgetAction
 
 from tpDcc.libs.python import python
-from tpDcc.libs.qt.core import mixin, qtutils, formatters
+from tpDcc.libs.resources.core import theme
+from tpDcc.libs.qt.core import qtutils, formatters
 
 
-@mixin.theme_mixin
+@theme.mixin
 # @mixin.property_mixin
 class BaseMenu(QMenu, object):
 
@@ -187,7 +188,7 @@ class Menu(QMenu, object):
         :return: QAction
         """
 
-        if isinstance(before, (unicode, str)):
+        if python.is_string(before):
             before = self.find_action(before)
 
         return super(Menu, self).insertAction(before, *args)
@@ -201,7 +202,7 @@ class Menu(QMenu, object):
         :return: QAction
         """
 
-        if isinstance(before, (unicode, str)):
+        if python.is_string(before):
             before = self.find_action(before)
 
         return super(Menu, self).insertMenu(before, menu)
@@ -213,7 +214,7 @@ class Menu(QMenu, object):
         :return: QAction
         """
 
-        if isinstance(before, (unicode, str)):
+        if python.is_string(before):
             before = self.find_action(before)
 
         return super(Menu, self).insertSeparator(before)
