@@ -8,36 +8,34 @@ Utility module that contains useful utilities functions for PySide
 from __future__ import print_function, division, absolute_import
 
 import os
-import re
 import sys
+import struct
 import logging
 import inspect
-import subprocess
 import contextlib
-from xml.etree import ElementTree
 
-try:
-    from cStringIO import StringIO
-except ImportError:
-    from io import StringIO
+from tpDcc import dcc
+from tpDcc.libs.python import python
+from tpDcc.libs.resources.core import color
 
-from tpDcc.libs.python import python, fileio, strings, path
+from tpDcc.libs.qt.core import consts
+
+LOGGER = logging.getLogger(consts.LIB_ID)
 
 QT_ERROR_MESSAGE = 'Qt.py is not available and Qt related functionality will not be available!'
 
 QT_AVAILABLE = True
-UILOADER_AVAILABLE = True
-PYSIDEUIC_AVAILABLE = True
 try:
-    from Qt.QtCore import *
-    from Qt.QtWidgets import *
-    from Qt.QtGui import *
+    from Qt.QtCore import Qt, Signal, QObject, QPoint, QSize
+    from Qt.QtWidgets import QApplication, QLayout, QVBoxLayout, QHBoxLayout, QWidget, QFrame, QLabel, QPushButton
+    from Qt.QtWidgets import QSizePolicy, QMessageBox, QInputDialog, QFileDialog, QMenu, QMenuBar
+    from Qt.QtGui import QFontDatabase, QPixmap, QIcon, QColor
     from Qt import QtGui
     from Qt import QtCompat
     from Qt import __binding__
 except ImportError as e:
     QT_AVAILABLE = False
-    print('Impossible to load Qt libraries. Qt dependant functionality will be disabled!')
+    LOGGER.warning('Impossible to load Qt libraries. Qt dependant functionality will be disabled!')
 
 if QT_AVAILABLE:
     if __binding__ == 'PySide2':
@@ -45,12 +43,6 @@ if QT_AVAILABLE:
             import shiboken2 as shiboken
         except ImportError:
             from PySide2 import shiboken2 as shiboken
-        try:
-            import pyside2uic as pysideuic
-        except ImportError:
-            PYSIDEUIC_AVAILABLE = False
-        from PySide2.QtCore import QMetaObject
-        from PySide2.QtUiTools import QUiLoader
     elif __binding__ == 'PySide':
         try:
             import shiboken
@@ -63,41 +55,21 @@ if QT_AVAILABLE:
                 except Exception:
                     pass
 
-        try:
-            import pysideuic
-        except ImportError:
-            PYSIDEUIC_AVAILABLE = False
-        from PySide.QtCore import QMetaObject
-        try:
-            from PySide.QtUiTools import QUiLoader
-        except ImportError:
-            try:
-                from tpDcc.libs.qt.externals.pysideutils.QtUiTools import QUiLoader
-            except ImportError:
-                UILOADER_AVAILABLE = False
-    else:
-        UILOADER_AVAILABLE = False
-        PYSIDEUIC_AVAILABLE = False
-
-import tpDcc
-from tpDcc.libs import qt
-from tpDcc.libs.qt.core import consts, color
-from tpDcc.libs.python import mathlib
-
 # ==============================================================================
 
+MAX_INT = 2 ** (struct.Struct('i').size * 8 - 1) - 1
+
 UI_EXTENSION = '.ui'
 QWIDGET_SIZE_MAX = (1 << 24) - 1
-FLOAT_RANGE_MIN = 0.1 + (-mathlib.MAX_INT - 1.0)
-FLOAT_RANGE_MAX = mathlib.MAX_INT + 0.1
-INT_RANGE_MIN = -mathlib.MAX_INT
-INT_RANGE_MAX = mathlib.MAX_INT
+FLOAT_RANGE_MIN = 0.1 + (-MAX_INT - 1.0)
+FLOAT_RANGE_MAX = MAX_INT + 0.1
+INT_RANGE_MIN = -MAX_INT
+INT_RANGE_MAX = MAX_INT
+CURRENT_DIR = os.path.expanduser('~')
+
 
 # ==============================================================================
 
-LOGGER = logging.getLogger()
-
-
 def is_pyqt():
     """
     Returns True if the current Qt binding is PyQt
@@ -168,111 +140,16 @@ def get_ui_library():
     return qt
 
 
-if UILOADER_AVAILABLE:
-    class UiLoader(QUiLoader):
-        """
-        Custom UILoader that support custom widgets definition
-        Qt.py QtCompat module does not handles custom widgets very well
-        This class create the user interface in the given baseinstance instance. If not given,
-        created widget is returned
-
-        https://github.com/spyder-ide/qtpy/blob/master/qtpy/uic.py
-        https://gist.github.com/cpbotha/1b42a20c8f3eb9bb7cb8
-        """
-
-        def __init__(self, baseinstance, customWidgets=None):
-            """
-            Constructor
-            :param baseinstance: loaded user interface is created in the given baseinstance which
-            must be an instance of the top-level class in the UI to load, or a subclass thereof
-            :param customWidgets: dict, dict mapping from class name to class object for custom widgets
-            """
-            super(UiLoader, self).__init__(baseinstance)
-
-            self.baseinstance = baseinstance
-
-            if customWidgets is None:
-                self.customWidgets = {}
-            else:
-                self.customWidgets = customWidgets
-
-        def createWidget(self, class_name, parent=None, name=''):
-            """
-            Function that is called for each widget defined in ui file,
-            overridden here to populate baseinstance instead.
-            """
-
-            if parent is None and self.baseinstance:
-                # supposed to create the top-level widget, return the base
-                # instance instead
-                return self.baseinstance
-
-            else:
-
-                # For some reason, Line is not in the list of available
-                # widgets, but works fine, so we have to special case it here.
-                if class_name in self.availableWidgets() or class_name == 'Line':
-                    # create a new widget for child widgets
-                    widget = QUiLoader.createWidget(self, class_name, parent, name)
-
-                else:
-                    # If not in the list of availableWidgets, must be a custom
-                    # widget. This will raise KeyError if the user has not
-                    # supplied the relevant class_name in the dictionary or if
-                    # customWidgets is empty.
-                    try:
-                        widget = self.customWidgets[class_name](parent)
-                    except KeyError:
-                        raise Exception('No custom widget ' + class_name + ' '
-                                        'found in customWidgets')
-
-                if self.baseinstance:
-                    # set an attribute for the new child widget on the base
-                    # instance, just like PyQt4.uic.loadUi does.
-                    setattr(self.baseinstance, name, widget)
-
-                return widget
-
-        @staticmethod
-        def get_custom_widgets(ui_file):
-            """
-            This function is used to parse a ui file and look for the <customwidgets>
-            section, then automatically load all the custom widget classes.
-            """
-
-            import importlib
-            from xml.etree.ElementTree import ElementTree
-
-            etree = ElementTree()
-            ui = etree.parse(ui_file)
-
-            custom_widgets = ui.find('customwidgets')
-
-            if custom_widgets is None:
-                return {}
-
-            custom_widget_classes = {}
-
-            for custom_widget in custom_widgets.getchildren():
-
-                cw_class = custom_widget.find('class').text
-                cw_header = custom_widget.find('header').text
-
-                module = importlib.import_module(cw_header)
-
-                custom_widget_classes[cw_class] = getattr(module, cw_class)
-
-            return custom_widget_classes
-
-
 def wrapinstance(ptr, base=None):
     if ptr is None:
         return None
 
-    ptr = long(ptr)
+    ptr_type = long if python.is_python2() else int
+
+    ptr = ptr_type(ptr)
     if 'shiboken' in globals():
         if base is None:
-            qObj = shiboken.wrapInstance(long(ptr), QObject)
+            qObj = shiboken.wrapInstance(ptr_type(ptr), QObject)
             meta_obj = qObj.metaObject()
             cls = meta_obj.className()
             super_cls = meta_obj.superClass().className()
@@ -283,13 +160,13 @@ def wrapinstance(ptr, base=None):
             else:
                 base = QWidget
         try:
-            return shiboken.wrapInstance(long(ptr), base)
+            return shiboken.wrapInstance(ptr_type(ptr), base)
         except Exception:
             from PySide.shiboken import wrapInstance
-            return wrapInstance(long(ptr), base)
+            return wrapInstance(ptr_type(ptr), base)
     elif 'sip' in globals():
         base = QObject
-        return shiboken.wrapinstance(long(ptr), base)
+        return shiboken.wrapinstance(ptr_type(ptr), base)
     else:
         print('Failed to wrap object ...')
         return None
@@ -300,7 +177,10 @@ def unwrapinstance(object):
     Unwraps objects with PySide
     """
 
-    return long(shiboken.getCppPointer(object)[0])
+    if python.is_python2():
+        return long(shiboken.getCppPointer(object)[0])
+    else:
+        return int(shiboken.getCppPointer(object)[0])
 
 
 @contextlib.contextmanager
@@ -403,323 +283,11 @@ def compat_ui_loader(ui_file, widget=None):
         return ui
     else:
         for member in dir(ui):
-            if not member.startswith('__') and member is not 'staticMetaObject':
+            if not member.startswith('__') and member != 'staticMetaObject':
                 setattr(widget, member, getattr(ui, member))
         return ui
 
 
-def load_ui(ui_file, parent_widget=None):
-    """
-    Loads GUI from .ui file
-    :param ui_file: str, path to the UI file
-    :param parent_widget: QWidget, base instance widget
-    :param force_pyside: bool, True to force using PySide1 load UI.
-        Sometimes PySide2 gives error when working with custom widgets
-    """
-
-    if not QT_AVAILABLE:
-        qt.logger.error(QT_ERROR_MESSAGE)
-        return None
-
-    if not UILOADER_AVAILABLE:
-        qt.logger.error('QtUiLoader is not available, impossible teo load ui file!')
-        return None
-
-    customWidgets = UiLoader.get_custom_widgets(ui_file)
-    loader = UiLoader(parent_widget, customWidgets)
-    # if workingDirectory is not None:
-    #     loader.setWorkingDirectory(workingDirectory)
-    widget = loader.load(ui_file)
-    QMetaObject.connectSlotsByName(widget)
-    return widget
-
-
-def load_ui_type(ui_file):
-    """
-    Loads UI Designer file (.ui) and parse the file
-    :param ui_file: str, path to the UI file
-    """
-
-    if not QT_AVAILABLE:
-        qt.logger.warning(QT_ERROR_MESSAGE)
-        return None, None
-
-    if not PYSIDEUIC_AVAILABLE:
-        qt.logger.warning('pysideuic is not available. UI compilation functionality is not available!')
-        return None, None
-
-    parsed = ElementTree.parse(ui_file)
-    widget_class = parsed.find('widget').get('class')
-    form_class = parsed.find('class').text
-    with open(ui_file, 'r') as f:
-        o = StringIO()
-        frame = {}
-        pysideuic.compileUi(f, o, indent=0)
-        pyc = compile(o.getvalue(), '<string>', 'exec')
-        exec(pyc in frame)
-        # Fetch the base_class and form class based on their type in the XML from designer
-        form_class = frame['Ui_{}'.format(form_class)]
-        base_class = eval('{}'.format(widget_class))
-
-    return form_class, base_class
-
-
-def compile_ui(ui_file, py_file):
-    """
-    Compiles a Py. file from Qt Designer .ui file
-    :param ui_file: str
-    :param py_file: str
-    :return:
-    """
-
-    if not QT_AVAILABLE:
-        qt.logger.warning(QT_ERROR_MESSAGE)
-        return
-
-    if not PYSIDEUIC_AVAILABLE:
-        qt.logger.warning('pysideuic is not available. UI compilation functionality is not available!')
-        return
-
-    if not os.path.isfile(ui_file):
-        qt.logger.warning('UI file "{}" does not exists!'.format(ui_file))
-        return
-
-    if os.path.isfile(ui_file):
-        f = open(py_file, 'w')
-        pysideuic.compileUi(ui_file, f, False, 4, False)
-        f.close()
-
-
-def compile_uis(root_path, recursive=True, use_qt=True):
-    """
-    Loops through all files starting from root_path and compiles all .ui files
-    :param root_path: str, path where we want to compiles uis from
-    :param recursive: bool, Whether to compile only ui files on given path or compiles all paths recursively
-    :param use_qt: bool, Whether to use Qt.py when importing Qt modules or use default PySide modules
-    """
-
-    if not QT_AVAILABLE:
-        qt.logger.warning(QT_ERROR_MESSAGE)
-        return
-
-    if not os.path.exists(root_path):
-        qt.logger.error('Impossible to compile UIs because path "{}" is not valid!'.format(root_path))
-        return
-
-    if recursive:
-        for root, _, files in os.walk(root_path):
-            for f in files:
-                if f.endswith('.ui'):
-                    ui_file = os.path.join(root, f)
-
-                    py_file = ui_file.replace('.ui', '_ui.py')
-
-                    qt.logger.debug('> COMPILING: {}'.format(ui_file))
-                    compile_ui(ui_file=ui_file, py_file=py_file)
-
-                    # pysideuic will use the proper Qt version used to compile it when generating .ui Python code
-                    # pysideuic: PySide | pysideuic2: PySide2
-                    # Here we replace PySide usage with Qt.py module usage
-                    if os.path.exists(py_file) and use_qt:
-
-                        fileio.replace(py_file, 'QtGui.', '')
-                        fileio.replace(py_file, 'QtCore.', '')
-                        fileio.replace(py_file, 'QtWidgets.', '')
-
-                        out_lines = ''
-                        lines = open(py_file, 'r').readlines()
-                        for line in lines:
-                            if 'from PySide' in line or 'from PySide2' in line:
-                                line = 'try:\n\tfrom PySide.QtCore import *\n\tfrom PySide.QtGui import ' \
-                                       '*\nexcept:\n\tfrom PySide2.QtCore import *\n\tfrom PySide2.QtWidgets import ' \
-                                       '*\n\tfrom PySide2.QtGui import *\nfrom Qt import __binding__\n\n'
-                            if 'QApplication.UnicodeUTF8' in line:
-                                line = line.replace('QApplication.UnicodeUTF8',
-                                                    'QApplication.UnicodeUTF8 if __binding__ == "PySide" else -1')
-                            elif '-1' in line:
-                                line = line.replace('-1', 'QApplication.UnicodeUTF8 if __binding__ == "PySide" else -1')
-
-                            out_lines += '%s' % line
-                        out = open(py_file, 'w')
-                        out.writelines(out_lines)
-                        out.close()
-    else:
-        raise NotImplementedError()
-
-
-def clean_compiled_uis(root_path, recusive=True):
-    """
-    Loops through all files starting from root_path and removes all compile ui files
-    :param root_path: str, path where we want to compiles uis from
-    :param recursive: bool, Whether to compile only compiled ui files on given path or removes all paths recursively
-    """
-
-    if recusive:
-        for root, _, files in os.walk(root_path):
-            for f in files:
-                if f.endswith('_ui.py') or f.endswith('_ui.pyc'):
-                    os.remove(os.path.join(root, f))
-                    qt.logger.debug('Removed compiled UI: "{}"'.format(os.path.join(root, f)))
-
-
-def create_python_qrc_file(qrc_file, py_file):
-
-    """
-    Creates a Python file from a QRC file
-    :param src_file: str, QRC file name
-    """
-
-    if not os.path.isfile(qrc_file):
-        return
-
-    pyside_rcc_exe_path = 'C:\\Python27\\Lib\\site-packages\\PySide\\pyside-rcc.exe'
-    # pyside_rcc_exe_path = os.path.join(os.path.dirname(
-    # os.path.dirname(os.path.abspath(__file__))), 'externals', 'pyside-rcc', 'pyside-rcc.exe')
-    if not os.path.isfile(pyside_rcc_exe_path):
-        print('RCC_EXE_PATH_DOES_NOT_EXISTS!!!!!!!!!!!!!')
-    #     pyside_rcc_exe_path = filedialogs.OpenFileDialog(
-    #         title='Select pyside-rcc.exe location folder ...',
-    #     )
-    #     pyside_rcc_exe_path.set_directory('C:\\Python27\\Lib\\site-packages\\PySide')
-    #     pyside_rcc_exe_path.set_filters('EXE files (*.exe)')
-    #     pyside_rcc_exe_path = pyside_rcc_exe_path.exec_()
-    # if not os.path.isfile(pyside_rcc_exe_path):
-        return
-    # py_out = os.path.splitext(os.path.basename(src_file))[0]+'.py'
-    # py_out_path = os.path.join(os.path.dirname(src_file), py_out)
-    try:
-        subprocess.check_output('"{0}" -o "{1}" "{2}"'.format(pyside_rcc_exe_path, py_file, qrc_file))
-    except subprocess.CalledProcessError as e:
-        raise RuntimeError('command {0} returned with error (code: {1}): {2}'.format(e.cmd, e.returncode, e.output))
-    if not os.path.isfile(py_file):
-        return
-
-    fileio.replace(py_file, "from PySide import QtCore", "from Qt import QtCore")
-
-
-def create_qrc_file(src_paths, dst_file):
-
-    def _default_filter(x):
-        return not x.startswith(".")
-
-    def tree(top='.',
-             filters=None,
-             output_prefix=None,
-             max_level=4,
-             followlinks=False,
-             top_info=False,
-             report=True):
-        # The Element of filters should be a callable object or
-        # is a byte array object of regular expression pattern.
-        topdown = True
-        total_directories = 0
-        total_files = 0
-
-        top_fullpath = os.path.realpath(top)
-        top_par_fullpath_prefix = os.path.dirname(top_fullpath)
-
-        if top_info:
-            lines = top_fullpath
-        else:
-            lines = ""
-
-        if filters is None:
-            filters = [_default_filter]
-
-        for root, dirs, files in os.walk(top=top_fullpath, topdown=topdown, followlinks=followlinks):
-            assert root != dirs
-
-            if max_level is not None:
-                cur_dir = strings.strips(root, top_fullpath)
-                path_levels = strings.strips(cur_dir, "/").count("/")
-                if path_levels > max_level:
-                    continue
-
-            total_directories += len(dirs)
-            total_files += len(files)
-
-            for filename in files:
-                for _filter in filters:
-                    if callable(_filter):
-                        if not _filter(filename):
-                            total_files -= 1
-                            continue
-                    elif not re.search(_filter, filename, re.UNICODE):
-                        total_files -= 1
-                        continue
-
-                    if output_prefix is None:
-                        cur_file_fullpath = os.path.join(top_par_fullpath_prefix, root, filename)
-                    else:
-                        buf = strings.strips(os.path.join(root, filename), top_fullpath)
-                        if output_prefix != "''":
-                            cur_file_fullpath = os.path.join(output_prefix, buf.strip('/'))
-                        else:
-                            cur_file_fullpath = buf
-
-                    lines = "%s%s%s" % (lines, os.linesep, cur_file_fullpath)
-
-        lines = lines.lstrip(os.linesep)
-
-        if report:
-            report = "%d directories, %d files" % (total_directories, total_files)
-            lines = "%s%s%s" % (lines, os.linesep * 2, report)
-
-        return lines
-
-    def scan_files(src_path="."):
-        filters = ['.(png|jpg|gif)$']
-        output_prefix = './'
-        report = False
-        lines = tree(src_path, filters=filters, output_prefix=output_prefix, report=report)
-
-        lines = lines.split('\n')
-        if "" in lines:
-            lines.remove("")
-
-        return lines
-
-    def create_qrc_body(src_path, root_res_path, use_alias=True):
-
-        res_folder_files = path.get_absolute_file_paths(src_path)
-        lines = [os.path.relpath(f, root_res_path) for f in res_folder_files]
-
-        if use_alias:
-            buf = ['\t\t<file alias="{0}">{1}</file>\n'.format(os.path.splitext(
-                os.path.basename(i))[0].lower().replace('-', '_'), i).replace('\\', '/') for i in lines]
-        else:
-            buf = ["\t\t<file>{0}</file>\n".format(i).replace('\\', '/') for i in lines]
-        buf = "".join(buf)
-        # buf = QRC_TPL % buf
-        return buf
-
-    # Clean existing resources files and append initial resources header text
-    if dst_file:
-        parent = os.path.dirname(dst_file)
-        if not os.path.exists(parent):
-            os.makedirs(parent)
-        f = file(dst_file, "w")
-        f.write('<RCC>\n')
-
-        try:
-            for res_folder in src_paths:
-                res_path = os.path.dirname(res_folder)
-                start_header = '\t<qresource prefix="{0}">\n'.format(os.path.basename(res_folder))
-                qrc_body = create_qrc_body(res_folder, res_path)
-                end_header = '\t</qresource>\n'
-                res_text = start_header + qrc_body + end_header
-
-                f = file(dst_file, 'a')
-                f.write(res_text)
-
-            # Write end header
-            f = file(dst_file, "a")
-            f.write('</RCC>')
-            f.close()
-        except RuntimeError:
-            f.close()
-
-
 def get_signals(class_obj):
     """
     Returns a list with all signals of a class
@@ -732,6 +300,18 @@ def get_signals(class_obj):
     return result
 
 
+def safe_disconnect_signal(signal):
+    """
+    Disconnects given signal in a safe way
+    :param signal: Signal
+    """
+
+    try:
+        signal.disconnect()
+    except Exception:
+        pass
+
+
 def safe_delete_later(widget):
     """
     calls the deleteLater method on the given widget, but only
@@ -805,6 +385,18 @@ def clear_layout(layout):
     #             w.setParent(None)
 
 
+def clear_stack_widget(stack_widget):
+    """
+    Clears all the widgets stacked in the given stack widget
+    :param stack_widget: QStackWidget
+    """
+
+    for i in range(stack_widget.count(), 0, -1):
+        widget = stack_widget.widget(i)
+        stack_widget.removeWidget(widget)
+        widget.deleteLater()
+
+
 def layout_items(layout):
     """
     Returns the items from the given layout and returns them
@@ -879,6 +471,14 @@ def get_rounded_mask(width, height, radius_tl=10, radius_tr=10, radius_bl=10, ra
 
 
 def distance_point_to_line(p, v0, v1):
+    """
+    Returns the distance from the given point to line created by the two given v0 and v1 points
+    :param p: QPoint
+    :param v0: QPoint
+    :param v1: QPoint
+    :return:
+    """
+
     v = QtGui.QVector2D(v1 - v0)
     w = QtGui.QVector2D(p - v0)
     c1 = QtGui.QVector2D.dotProduct(w, v)
@@ -890,12 +490,19 @@ def distance_point_to_line(p, v0, v1):
 
 def qhash(inputstr):
     instr = ""
-    if isinstance(inputstr, str):
-        instr = inputstr
-    elif isinstance(inputstr, unicode):
-        instr = inputstr.encode("utf8")
+
+    if python.is_python2():
+        if isinstance(inputstr, str):
+            instr = inputstr
+        elif isinstance(inputstr, unicode):
+            instr = inputstr.encode("utf8")
+        else:
+            return -1
     else:
-        return -1
+        if python.is_string(inputstr):
+            instr = inputstr
+        else:
+            return -1
 
     h = 0x00000000
     for i in range(0, len(instr)):
@@ -958,7 +565,7 @@ def close_and_cleanup(widget):
         widget.deleteLater()
 
 
-def get_string_input(message, title='Rename', old_name=None):
+def get_string_input(message, title='Rename', old_name=None, parent=None):
     """
     Shows a Input dialog to allow the user to input a new string
     :param message: str, mesage to show in the dialog
@@ -967,7 +574,7 @@ def get_string_input(message, title='Rename', old_name=None):
     :return: str, new name
     """
 
-    dialog = QInputDialog()
+    dialog = QInputDialog(parent)
     flags = dialog.windowFlags() ^ Qt.WindowContextHelpButtonHint | Qt.WindowStaysOnTopHint
 
     if not old_name:
@@ -1048,7 +655,7 @@ def get_permission(message=None, cancel=True, title='Permission', parent=None):
     :return: bool
     """
 
-    message_box = QMessageBox()
+    message_box = QMessageBox(parent=parent)
     message_box.setWindowTitle(title)
     flags = message_box.windowFlags() ^ Qt.WindowContextHelpButtonHint | Qt.WindowStaysOnTopHint
     if message:
@@ -1080,7 +687,7 @@ def get_save_permission(message, file_path=None, title='Permission', parent=None
     :return: bool
     """
 
-    message_box = QMessageBox()
+    message_box = QMessageBox(parent=parent)
     message_box.setWindowTitle(title)
     flags = message_box.windowFlags() ^ Qt.WindowContextHelpButtonHint | Qt.WindowStaysOnTopHint
     if file_path:
@@ -1379,6 +986,32 @@ def create_flat_button(
     return btn
 
 
+def create_vertical_line():
+    """
+    Creates and returns a new vertical line
+    :return: QFrame
+    """
+
+    line_frame = QFrame()
+    line_frame.setFrameShape(QFrame.VLine)
+    line_frame.setFrameShadow(QFrame.Sunken)
+
+    return line_frame
+
+
+def create_horizontal_line():
+    """
+    Creates and returns a new horizontal line
+    :return: QFrame
+    """
+
+    line_frame = QFrame()
+    line_frame.setFrameShape(QFrame.HLine)
+    line_frame.setFrameShadow(QFrame.Sunken)
+
+    return line_frame
+
+
 def get_or_create_menu(menu_bar, menu_title):
     """
     Creates a new menu in the given menubar with the given menubar or return Menu object if the a menu
@@ -1500,7 +1133,7 @@ def get_window_menu_bar(window=None):
     :return: QMenuBar or None
     """
 
-    window = window or tpDcc.Dcc.get_main_window()
+    window = window or dcc.get_main_window()
     if not window:
         return
 
@@ -1743,3 +1376,101 @@ def process_ui_events():
     """
 
     QApplication.processEvents()
+
+
+def get_main_qt_window():
+    """
+    Returns QWidget representing the top most window
+    :return: QWidget
+    """
+
+    parent = QApplication.activeWindow()
+    grand_parent = parent
+    while grand_parent is not None:
+        parent = grand_parent
+        grand_parent = parent.parent()
+
+    return parent
+
+
+def center_widget_on_screen(widget):
+    """
+    Centers a given QWidget on the active screen
+    :param widget: QWidget
+    """
+
+    frame_geo = widget.frameGeometry()
+    screen = QApplication.desktop().screenNumber(QApplication.desktop().cursor().pos())
+    center_point = QApplication.desktop().screenGeometry(screen).center()
+    frame_geo.moveCenter(center_point)
+    widget.move(frame_geo.topLeft())
+
+
+def restore_cursor():
+    """
+    Restores current Qt application cursor
+    """
+
+    QApplication.restoreOverrideCursor()
+
+
+def set_wait_cursor(state=True):
+    """
+    Sets the wait cursor as the cursor for current Qt application
+    """
+
+    if state:
+        QApplication.setOverrideCursor(Qt.WaitCursor)
+    else:
+        restore_cursor()
+
+
+def set_current_directory(path):
+    """
+    Updates global current directory
+    :param path: str, new current directory
+    """
+
+    global CURRENT_DIR
+    if os.path.isdir(path):
+        CURRENT_DIR = path
+    elif os.path.isfile(path):
+        CURRENT_DIR = os.path.dirname(path)
+
+
+def get_save_filename(title='Save File', file_dir=None, ext_filter='*', parent=None):
+    """
+    Opens a save file dialog
+    :param title: str
+    :param file_dir: str
+    :param ext_filter: str
+    :param parent: QWidget
+    :return: str, selected file path
+    """
+
+    file_dir = file_dir or CURRENT_DIR
+    file_dialog = QFileDialog.getSaveFileName(parent, title, file_dir, ext_filter)
+    file_path = file_dialog[0] or None
+    if file_path:
+        set_current_directory(file_path)
+
+    return file_dialog
+
+
+def get_open_filename(title='Open File', file_dir=None, ext_filter='*', parent=None):
+    """
+    Opens an open file dialog
+    :param title: str
+    :param file_dir: str
+    :param ext_filter: str
+    :param parent: QWidget
+    :return: str, selected file path
+    """
+
+    file_dir = file_dir or CURRENT_DIR
+    file_dialog = QFileDialog.getOpenFileName(parent, title, file_dir, ext_filter)
+    file_path = file_dialog[0] or None
+    if file_path:
+        set_current_directory(file_path)
+
+    return file_dialog
