@@ -12,10 +12,7 @@ import sys
 import inspect
 import logging
 
-from Qt.QtWidgets import *
-from tpDcc.libs.qt import register
-from tpDcc.libs.qt.core import window, dialog
-from tpDcc.libs.qt.managers import inputs as inputs_manager, toolsets as toolsets_manager
+from Qt.QtWidgets import QApplication
 
 # =================================================================================
 
@@ -28,29 +25,15 @@ main = __import__('__main__')
 def init(dev=False):
     """
     Initializes module
-    :param do_reload: bool, Whether to reload modules or not
-    :param dev: bool, Whether artellapipe is initialized in dev mode or not
+    :param dev: bool, Whether tpDcc-libs-qt is initialized in dev mode or not
     """
 
-    from tpDcc import register as dcc_register
-
-    if dev:
-        register.cleanup()
-
     logger = create_logger(dev=dev)
 
-    register.register_class('logger', logger)
-
     # NOTE: We register all classes using tpDcc register (not tpDcc.libs.qt one).
-    # We do it in this way to access those classes easily
-    dcc_register.register_class('Window', window.MainWindow)
-    dcc_register.register_class('Dialog', dialog.Dialog)
-    dcc_register.register_class('OpenFileDialog', dialog.OpenFileDialog)
-    dcc_register.register_class('SaveFileDialog', dialog.SaveFileDialog)
-    dcc_register.register_class('SelectFolderDialog', dialog.SelectFolderDialog)
-    dcc_register.register_class('NativeDialog', dialog.NativeDialog)
-    dcc_register.register_class('InputsMgr', inputs_manager.InputsManagerSingleton)
-    dcc_register.register_class('ToolsetsMgr', toolsets_manager.ToolsetsManagerSingleton)
+    # # We do it in this way to access those classes easily
+    # dcc_register.register_class('InputsMgr', inputs_manager.InputsManagerSingleton)
+    # dcc_register.register_class('ToolsetsMgr', toolsets_manager.ToolsetsManagerSingleton)
 
     def init_dcc():
         """
@@ -58,41 +41,38 @@ def init(dev=False):
         """
 
         dcc_loaded = False
-        if 'cmds' in main.__dict__:
-            from tpDcc.dccs.maya import loader as dcc_loader
-            dcc_loaded = True
-        elif 'MaxPlus' in main.__dict__:
-            from tpDcc.dccs.max import loader as dcc_loader
-            dcc_loaded = True
-        elif 'hou' in main.__dict__:
-            from tpDcc.dccs.houdini import loader as dcc_loader
-            dcc_loaded = True
-        elif 'nuke' in main.__dict__:
-            from tpDcc.dccs.nuke import loader as dcc_loader
-            dcc_loaded = True
-        else:
-            try:
-                import unreal
-                from tpDcc.dccs.unreal import loader as dcc_loader
+        try:
+            if 'cmds' in main.__dict__:
+                from tpDcc.dccs.maya import loader as dcc_loader
                 dcc_loaded = True
-            except Exception as exc:
-                pass
+            elif 'MaxPlus' in main.__dict__:
+                from tpDcc.dccs.max import loader as dcc_loader
+                dcc_loaded = True
+            elif 'hou' in main.__dict__:
+                from tpDcc.dccs.houdini import loader as dcc_loader
+                dcc_loaded = True
+            elif 'nuke' in main.__dict__:
+                from tpDcc.dccs.nuke import loader as dcc_loader
+                dcc_loaded = True
+            else:
+                try:
+                    import unreal
+                    from tpDcc.dccs.unreal import loader as dcc_loader
+                    dcc_loaded = True
+                except Exception:
+                    pass
+        except ImportError:
+            logger.warning('Impossible to setup DCC. DCC not found. Abstract one will be used.')
+        except Exception as exc:
+            logger.warning('Error while setting DCC: {}. Abstract one will be used.'.format(exc))
 
         if dcc_loaded:
-            dcc_loader.init_ui()
-        if not dcc_loaded:
-            global Dcc
-            from tpDcc.core import dcc
-            Dcc = dcc.UnknownDCC
-            logger.warning('No DCC found, using abstract one!')
+            if hasattr(dcc_loader, 'init_ui') and callable(dcc_loader.init_ui):
+                dcc_loader.init_ui()
 
     app = QApplication.instance() or QApplication(sys.argv)
 
     update_paths()
-    register_resources()
-
-    # skip_modules = ['{}.{}'.format(PACKAGE, name) for name in ['loader', 'externals']]
-    # importer.init_importer(package=PACKAGE, skip_modules=skip_modules)
 
     init_dcc()
 
@@ -152,6 +132,7 @@ def create_logger(dev=False):
 
     logging.config.fileConfig(logging_config, disable_existing_loggers=False)
     logger = logging.getLogger(PACKAGE.replace('.', '-'))
+    dev = os.getenv('TPDCC_DEV', dev)
     if dev:
         logger.setLevel(logging.DEBUG)
         for handler in logger.handlers:
@@ -160,13 +141,4 @@ def create_logger(dev=False):
     return logger
 
 
-def register_resources():
-    """
-    Registers tpDcc.libs.qt resources path
-    """
-
-    import tpDcc
-
-    resources_manager = tpDcc.ResourcesMgr()
-    resources_path = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'resources')
-    resources_manager.register_resource(resources_path, key='tpDcc-libs-qt')
+create_logger()
