@@ -9,7 +9,6 @@ from __future__ import print_function, division, absolute_import
 
 from collections import defaultdict
 
-from tpDcc.libs.python import decorators
 from tpDcc.libs.qt.core import input
 
 
@@ -54,9 +53,3 @@ class InputManager(object):
         """
 
         pass
-
-
-@decorators.Singleton
-class InputsManagerSingleton(InputManager, object):
-    def __init__(self):
-        InputManager.__init__(self)
