@@ -5,12 +5,18 @@
 Module that contains implementation for DCC toolsets
 """
 
+from __future__ import print_function, division, absolute_import
+
 import os
+import re
+import logging
 from collections import OrderedDict
 
-import tpDcc
-from tpDcc.core import plugin
-from tpDcc.libs.python import python, decorators, folder, yamlio, color
+from tpDcc.managers import configs
+from tpDcc.libs.python import python, color, decorators, folder, yamlio
+from tpDcc.libs.plugin.core import factory
+
+from tpDcc.libs.qt.core import consts
 from tpDcc.libs.qt.widgets import toolset
 
 if python.is_python2():
@@ -18,30 +24,34 @@ if python.is_python2():
 else:
     import importlib as loader
 
+logger = logging.getLogger(consts.LIB_ID)
 
-class ToolsetsPluginsManager(plugin.PluginsManager, object):
 
-    INTERFACE = toolset.ToolsetWidget
+@decorators.add_metaclass(decorators.Singleton)
+class ToolsetsManager(factory.PluginFactory):
+
+    REGEX_FOLDER_VALIDATOR = re.compile('^((?!__pycache__)(?!dccs).)*$')
 
     def __init__(self):
-        super(ToolsetsPluginsManager, self).__init__()
-
-
-class ToolsetsManager(object):
-    def __init__(self,):
-        super(ToolsetsManager, self).__init__()
+        super(ToolsetsManager, self).__init__(interface=toolset.ToolsetWidget)
 
         self._toolsets = dict()
         self._toolset_groups = dict()
-        self._registered_paths = dict()
+        self._registered_file_paths = dict()
 
-        self._manager = ToolsetsPluginsManager()
+    # ============================================================================================================
+    # PROPERTIES
+    # ============================================================================================================
 
     @property
     def toolset_groups(self):
         return self._toolset_groups
 
-    def register_path(self, package_name, path_to_register):
+    # ============================================================================================================
+    # TOOLSETS
+    # ============================================================================================================
+
+    def register_toolset_file_path(self, path_to_register, package_name=None):
         """
         Register path to find toolsets from
         :return: str
@@ -49,39 +59,32 @@ class ToolsetsManager(object):
 
         if not path_to_register or not os.path.isdir(path_to_register):
             return None
+        if package_name not in self._registered_file_paths:
+            self._registered_file_paths[package_name] = list()
+        if path_to_register not in self._registered_file_paths[package_name]:
+            self._registered_file_paths[package_name].append(path_to_register)
 
-        if package_name not in self._registered_paths:
-            self._registered_paths[package_name] = list()
-
-        if path_to_register not in self._registered_paths[package_name]:
-            self._registered_paths[package_name].append(path_to_register)
-
-    # ============================================================================================================
-    # TOOLSETS
-    # ============================================================================================================
-
-    def load_registered_toolsets(self, package_name, tools_to_load, tools_manager=None):
+    def load_registered_toolsets(self, package_name, tools_to_load):
         self._load_registered_paths_toolsets(package_name=package_name)
         self._load_package_toolsets(
             package_name=package_name, tools_to_load=tools_to_load)
 
-        tools_mgr = tools_manager or tpDcc.ToolsMgr
+        if package_name not in self._toolsets:
+            self._toolsets[package_name] = list()
+        toolset_data = self.plugins(package_name)
+        if not toolset_data:
+            return True
 
-        for pkg_name, toolset_data in self._manager.plugins.items():
-            if package_name != pkg_name:
-                continue
-            if package_name not in self._toolsets:
-                self._toolsets[package_name] = list()
-            for tool_set in toolset_data.values():
-                if tool_set.ID not in self._toolsets[package_name]:
-                    toolset_config = tools_mgr().get_tool_config(tool_set.ID, package_name=package_name)
-                    if not toolset_config:
-                        tpDcc.logger.warning(
-                            'No valid configuration file found for toolset: "{}" in package: "{}"'.format(
-                                tool_set.ID, package_name))
-                        continue
-                    tool_set.CONFIG = toolset_config
-                    self._toolsets[package_name].append({tool_set.ID: tool_set})
+        for tool_set in toolset_data:
+            if tool_set.ID not in self._toolsets[package_name]:
+                toolset_config = configs.get_tool_config(tool_set.ID, package_name=package_name)
+                if not toolset_config:
+                    logger.warning(
+                        'No valid configuration file found for toolset: "{}" in package: "{}"'.format(
+                            tool_set.ID, package_name))
+                    continue
+                tool_set.CONFIG = toolset_config
+                self._toolsets[package_name].append({tool_set.ID: tool_set})
 
         return True
 
@@ -99,7 +102,7 @@ class ToolsetsManager(object):
 
         package_toolsets = self._toolsets.get(package_name)
         if not package_toolsets:
-            tpDcc.logger.warning('No toolsets found in package: {}!'.format(package_name))
+            logger.warning('No toolsets found in package: {}!'.format(package_name))
             return None
 
         toolset_found = None
@@ -109,7 +112,8 @@ class ToolsetsManager(object):
                 break
 
         if not toolset_found:
-            raise KeyError('"Toolset "{}" not found in package: "{}".'.format(toolset_id, package_name))
+            logger.warning('Toolset "{}" not found in package: "{}".'.format(toolset_id, package_name))
+            return None
 
         if as_dict:
             return toolset_found
@@ -148,8 +152,15 @@ class ToolsetsManager(object):
         :return: list(ToolsetWidget)
         """
 
+        toolsets_found = list()
         toolset_ids = self.toolset_ids(group_type, package_name=package_name)
-        return [self.toolset(toolset_id, package_name=package_name, as_dict=as_dict) for toolset_id in toolset_ids]
+        for toolset_id in toolset_ids:
+            new_toolset = self.toolset(toolset_id, package_name=package_name, as_dict=as_dict)
+            if not new_toolset:
+                continue
+            toolsets_found.append(new_toolset)
+
+        return toolsets_found
 
     def toolset_widgets(self, package_name=None, sort=True):
         """
@@ -159,23 +170,23 @@ class ToolsetsManager(object):
         :return:
         """
 
-        tolset_widgets = list()
+        toolset_widgets = list()
 
         if package_name and package_name not in self._toolsets:
             return
 
         if package_name:
-            tolset_widgets = self._toolsets[package_name].values()
+            toolset_widgets = self._toolsets[package_name].values()
         else:
             for package_name, toolsets in self._toolsets.items():
-                for toolset in toolsets:
-                    for toolset_id, toolset_widget in toolset.items():
-                        tolset_widgets.append(toolset_widget)
+                for toolset_found in toolsets:
+                    for toolset_id, toolset_widget in toolset_found.items():
+                        toolset_widgets.append(toolset_widget)
 
         if sort:
-            tolset_widgets.sort(key=lambda toolset: toolset.CONFIG.get('name'))
+            toolset_widgets.sort(key=lambda toolset_widget_found: toolset_widget_found.CONFIG.get('name'))
 
-        return tolset_widgets
+        return toolset_widgets
 
     def toolset_color(self, toolset_id, package_name=None):
         """
@@ -202,10 +213,38 @@ class ToolsetsManager(object):
                         hue_shift = toolset_group['hue_shift'] * (index + 1)
                         return tuple(color.hue_shift(group_color, hue_shift))
         else:
-            tpDcc.logger.warning(
+            logger.warning(
                 'ToolSet "{}" not found in any toolset group. Impossible to retrieve color!'.format(toolset_id))
             return 255, 255, 255
 
+    def toolset_menu(self, toolset_type=None, package_name=None):
+        """
+        Returns the menu data of the given toolset
+        :param toolset_type: str
+        :param package_name: str
+        :return: list(list)
+        """
+
+        if not package_name:
+            package_name = toolset_type.replace('.', '-').split('-')[0]
+
+        toolset_menus = list()
+
+        if self._toolset_groups and package_name in self._toolset_groups:
+            for pkg_name, toolset_groups in self._toolset_groups.items():
+                if package_name != pkg_name:
+                    continue
+                for toolset_group in toolset_groups:
+                    if toolset_type:
+                        if toolset_group['type'] != toolset_type:
+                            continue
+                    toolset_menus.append(toolset_group.get('menu', list()))
+        else:
+            logger.warning(
+                'Toolset "{}" not found in any toolset group. Impossible to retrieve menu data!'.format(toolset_type))
+
+        return toolset_menus
+
     def group_types(self):
         found_group_types = list()
         for pkg_name, toolset_groups in self._toolset_groups.items():
@@ -232,6 +271,7 @@ class ToolsetsManager(object):
         """
         Returns color by group type
         :param group_type: str
+        :param package_name: str
         :return: str
         """
 
@@ -277,11 +317,11 @@ class ToolsetsManager(object):
         Loads all toolsets found in registered paths
         """
 
-        if not self._registered_paths:
+        if not self._registered_file_paths:
             return
 
         # Load toolsets data
-        for pkg_name, registered_paths in self._registered_paths.items():
+        for pkg_name, registered_paths in self._registered_file_paths.items():
             if package_name != pkg_name:
                 continue
             for registered_path in registered_paths:
@@ -292,7 +332,7 @@ class ToolsetsManager(object):
                     try:
                         toolset_data = yamlio.read_file(pth, maintain_order=True)
                     except Exception:
-                        tpDcc.logger.warning('Impossible to read toolset data from: "{}!'.format(pth))
+                        logger.warning('Impossible to read toolset data from: "{}!'.format(pth))
                         continue
                     if pkg_name not in self._toolset_groups:
                         self._toolset_groups[pkg_name] = list()
@@ -309,17 +349,16 @@ class ToolsetsManager(object):
                         self._toolset_groups[pkg_name].append(toolset_data)
 
         # Load toolsets widgets
-        for pkg_name, registered_paths in self._registered_paths.items():
+        for pkg_name, registered_paths in self._registered_file_paths.items():
             if package_name != pkg_name:
                 continue
-            self._manager.register_paths(registered_paths, package_name=pkg_name)
+            self.register_paths(registered_paths, package_name=pkg_name)
 
     def _load_package_toolsets(self, package_name, tools_to_load):
         """
         Loads all toolsets available in given package
         :param package_name: str
-        :param tools_to_load: lsit
-        :param dev: bool
+        :param tools_to_load: list
         """
 
         if not tools_to_load:
@@ -334,6 +373,7 @@ class ToolsetsManager(object):
             pkg_path = tools_path.format(package_name, tool_name)
             pkg_loader = loader.find_loader(pkg_path)
             if not pkg_loader:
+                logger.debug('No loader found for "{}"'.format(tool_name))
                 continue
             if tool_name not in paths_to_register:
                 paths_to_register[tool_name] = list()
@@ -342,16 +382,6 @@ class ToolsetsManager(object):
             if package_filename not in tools_paths_to_load:
                 tools_paths_to_load.append(package_filename)
 
-        # Find toolset widgets are located
+        # Find where toolset widgets are located
         if tools_paths_to_load:
-            self._manager.register_paths(tools_paths_to_load, package_name=package_name)
-
-
-@decorators.Singleton
-class ToolsetsManagerSingleton(ToolsetsManager, object):
-    """
-    Singleton class that holds preferences manager instance
-    """
-
-    def __init__(self):
-        ToolsetsManager.__init__(self)
+            self.register_paths(tools_paths_to_load, package_name=package_name)
