@@ -9,15 +9,16 @@ from __future__ import print_function, division, absolute_import
 
 from functools import partial
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
-from Qt.QtGui import *
+from Qt.QtCore import Qt, Signal, Property, QPoint, QSize, QRect, QTimer
+from Qt.QtWidgets import QApplication, QSizePolicy, QAbstractButton, QPushButton, QToolButton, QRadioButton
+from Qt.QtWidgets import QStyle, QStyleOptionButton, QStylePainter, QStyleOption
+from Qt.QtGui import QCursor, QIcon, QFontMetrics, QPainter, QPainterPath, QColor, QBrush, QLinearGradient
 
-from six import string_types
-
-import tpDcc as tp
+from tpDcc import dcc
+from tpDcc.managers import resources
 from tpDcc.libs.python import python
-from tpDcc.libs.qt.core import consts, animation, icon, qtutils, mixin, theme, menu
+from tpDcc.libs.resources.core import icon, theme
+from tpDcc.libs.qt.core import consts, animation, qtutils, menu
 from tpDcc.libs.qt.widgets import tooltips
 
 # ===================================================================
@@ -28,8 +29,8 @@ INNER, OUTER = 1, 2
 # ===================================================================
 
 
-@mixin.theme_mixin
-@mixin.cursor_mixin
+@theme.mixin
+# @mixin.cursor_mixin
 class BaseButton(QPushButton, object):
 
     class Types(object):
@@ -39,7 +40,11 @@ class BaseButton(QPushButton, object):
         WARNING = 'warning'
         DANGER = 'danger'
 
-    def __init__(self, text='', icon=None, parent=None):
+    def __init__(self, text='', icon=None, elided=False, parent=None):
+
+        self._text = text
+        self._elided = elided
+
         if not icon:
             super(BaseButton, self).__init__(text=text, parent=parent)
         else:
@@ -196,16 +201,29 @@ class BaseButton(QPushButton, object):
 
         return self
 
+    def setText(self, text):
+        self._text = text
+        super(BaseButton, self).setText(text)
 
-@mixin.theme_mixin
-@mixin.cursor_mixin
+    def resizeEvent(self, event):
+        if self._elided:
+            has_icon = self.icon() and not self.icon().isNull()
+            if has_icon:
+                font_metrics = QFontMetrics(self.font())
+                elided = font_metrics.elidedText(self._text, Qt.ElideMiddle, self.width() - 30)
+                super(BaseButton, self).setText(elided)
+        super(BaseButton, self).resizeEvent(event)
+
+
+@theme.mixin
+# @mixin.cursor_mixin
 class BaseRadioButton(QRadioButton, object):
     def __init__(self, *args, **kwargs):
         super(BaseRadioButton, self).__init__(*args, **kwargs)
 
 
-@mixin.theme_mixin
-@mixin.cursor_mixin
+@theme.mixin
+# @mixin.cursor_mixin
 class BaseToolButton(QToolButton, object):
     def __init__(self, parent=None):
         super(BaseToolButton, self).__init__(parent=parent)
@@ -257,9 +275,9 @@ class BaseToolButton(QToolButton, object):
             if theme:
                 accent_color = theme.accent_color
                 if self._image_theme:
-                    self.setIcon(tp.ResourcesMgr().icon(self._image, theme=self._image_theme, color=accent_color))
+                    self.setIcon(resources.icon(self._image, theme=self._image_theme, color=accent_color))
                 else:
-                    self.setIcon(tp.ResourcesMgr().icon(self._image, color=accent_color))
+                    self.setIcon(resources.icon(self._image, color=accent_color))
         return super(BaseToolButton, self).enterEvent(event)
 
     def leaveEvent(self, event):
@@ -272,9 +290,9 @@ class BaseToolButton(QToolButton, object):
             if image_theme:
                 kwargs['theme'] = image_theme
             if self.isCheckable() and self.isChecked():
-                self.setIcon(tp.ResourcesMgr().icon(self._image, **kwargs))
+                self.setIcon(resources.icon(self._image, **kwargs))
             else:
-                self.setIcon(tp.ResourcesMgr().icon(self._image, **kwargs))
+                self.setIcon(resources.icon(self._image, **kwargs))
 
     # =================================================================================================================
     # BASE
@@ -967,7 +985,11 @@ class BaseMenuButton(QPushButton, ButtonIcons):
         self.middleClicked.connect(partial(self._on_context_menu, Qt.MidButton))
         self.rightClicked.connect(partial(self._on_context_menu, Qt.RightButton))
 
-        self._double_click_interval = QApplication.instance().doubleClickInterval()     # default is 500
+        app = QApplication.instance()
+        if app and hasattr(app, 'doubleClickInterval') and callable(app.doubleClickInterval):
+            self._double_click_interval = QApplication.instance().doubleClickInterval()
+        else:
+            self._double_click_interval = 500
         self._double_click_enabled = double_click_enabled
 
     @property
@@ -1140,9 +1162,9 @@ class BaseMenuButton(QPushButton, ButtonIcons):
             if isinstance(action_icon, QIcon):
                 new_action.setIcon(action_icon)
                 new_action.setIconText(icon_text or '')
-            elif isinstance(action_icon, string_types):
+            elif python.is_string(action_icon):
                 new_action.setIconText(action_icon or icon_text or None)
-                action_icon = tp.ResourcesMgr().icon(action_icon)
+                action_icon = resources.icon(action_icon)
                 new_action.setIcon(
                     icon.colorize_layered_icon(action_icon, colors=[icon_color], size=qtutils.dpi_scale(icon_size)))
 
@@ -1319,7 +1341,7 @@ class ColorButton(QPushButton, object):
         self._update_color()
 
     def show_color_editor(self):
-        if tp.is_maya():
+        if dcc.is_maya():
             import maya.cmds as cmds
             cmds.colorEditor(rgbValue=(self._color.redF(), self._color.greenF(), self._color.blueF()))
             if not cmds.colorEditor(query=True, result=True):
@@ -1328,7 +1350,7 @@ class ColorButton(QPushButton, object):
             self.color = QColor.fromRgbF(new_color[0], new_color[1], new_color[2])
             self.colorChanged.emit()
         else:
-            raise RuntimeError('Code Editor is not available for DCC: {}'.format(tp.Dcc.get_name()))
+            raise RuntimeError('Code Editor is not available for DCC: {}'.format(dcc.get_name()))
 
     def _update_color(self):
         self.setStyleSheet(
@@ -1338,11 +1360,14 @@ class ColorButton(QPushButton, object):
     color = property(get_color, set_color)
 
 
-def get_axis_button(axis_type='x', parent=None):
+def get_axis_button(axis_type='x', parent=None, as_tool_button=True):
     axis = axis_type.lower() if axis_type else 'x'
     axis = axis if axis in consts.AXISES else 'x'
-    axis_btn = BaseToolButton(parent=parent)
-    axis_icon = tp.ResourcesMgr().icon('{}_axis'.format(axis), color=QColor(*consts.AXISES[axis]))
+    if as_tool_button:
+        axis_btn = BaseToolButton(parent=parent)
+    else:
+        axis_btn = BaseButton(parent=parent)
+    axis_icon = resources.icon('{}_axis'.format(axis), color=QColor(*consts.AXISES[axis]))
     axis_btn.setIcon(axis_icon)
 
     return axis_btn
