@@ -11,14 +11,30 @@ import math
 import array
 from functools import partial
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
-from Qt.QtGui import *
+from Qt.QtCore import Qt, Signal, Property, Slot, QSize, QSizeF, QPoint, QPointF, QRect, QRectF, QLineF, QMimeData
+from Qt.QtCore import qFuzzyCompare
+from Qt.QtWidgets import QStyle, QStyleOptionFrame, QStylePainter, QSizePolicy, QColorDialog, QDialogButtonBox
+from Qt.QtWidgets import QApplication, QWidget, QFrame, QDialog, QToolButton, QLineEdit, QSlider, QMenu
+from Qt.QtGui import QColor, QBrush, QPen, QPainter, QPainterPath, QGradient, QLinearGradient, QConicalGradient
+from Qt.QtGui import QPixmap, QImage, QPolygonF, QDrag
 
-import tpDcc as tp
-from tpDcc.libs.python import mathlib, python
-from tpDcc.libs.qt.core import base, qtutils, color as core_color
-from tpDcc.libs.qt.widgets import buttons, label, spinbox, dividers, panel
+from tpDcc.dcc import dialog
+from tpDcc.managers import resources
+from tpDcc.libs.python import python
+from tpDcc.libs.resources.core import color as core_color
+from tpDcc.libs.qt.core import base, utils, qtutils, contexts as qt_contexts
+from tpDcc.libs.qt.widgets import layouts, buttons, label, spinbox, dividers, panel, sliders
+
+
+# TODO: Move all defualt colors into a configuration file that can be ready by any widget
+DEFAULT_COLORS = {
+    'Grey': (102, 102, 102, 255),
+    'Ok': (128, 178, 204, 255),
+    'Cancel': (178, 128, 102, 255),
+    'Warn': (178, 51, 51, 255),
+    'Collapse': (38, 38, 38, 255),
+    'Subtle': (122, 122, 153, 255)
+}
 
 
 class ColorButton(buttons.BaseButton, object):
@@ -32,16 +48,14 @@ class ColorPicker(QFrame, object):
 
     colorChanged = Signal(object)
 
-    def __init__(self, *args):
-        super(ColorPicker, self).__init__(*args)
+    def __init__(self, *args, **kwargs):
+        super(ColorPicker, self).__init__(*args, **kwargs)
 
         self._buttons = list()
         self._current_color = None
         self._browser_colors = None
 
-        main_layout = QHBoxLayout()
-        main_layout.setContentsMargins(0, 0, 0, 0)
-        main_layout.setSpacing(0)
+        main_layout = layouts.HorizontalLayout(spacing=0, margins=(0, 0, 0, 0))
         self.setLayout(main_layout)
 
     def current_color(self):
@@ -106,7 +120,7 @@ class ColorPicker(QFrame, object):
             callback = partial(self._on_color_changed, color)
             css = 'background-color: {}'.format(color)
 
-            btn = self.COLOR_BUTTON_CLASS(self)
+            btn = self.COLOR_BUTTON_CLASS(parent=self)
             btn.setObjectName('colorButton')
             btn.setStyleSheet(css)
             btn.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
@@ -116,7 +130,7 @@ class ColorPicker(QFrame, object):
             self.layout().addWidget(btn)
             first = False
 
-        browse_btn = QPushButton('...', self)
+        browse_btn = buttons.BaseButton('...', parent=self)
         browse_btn.setObjectName('menuButton')
         browse_btn.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
         browse_btn.clicked.connect(self._on_browse_color)
@@ -261,9 +275,6 @@ class ColorSwatch(QToolButton, object):
 
     def _on_open_color_picker(self):
 
-        # THIS ONLY WORKS ON MAYA
-        from tpDcc.libs.qt.core import dialog
-
         color_picker = dialog.ColorDialog()
         color_picker.exec_()
         if color_picker.color is None:
@@ -299,7 +310,7 @@ class ColorLineEdit(QLineEdit, object):
         self._preview_color = True
         self._background = QBrush()
 
-        self._background.setTexture(QPixmap(tp.ResourcesMgr().pixmap('alpha_back')))
+        self._background.setTexture(QPixmap(resources.pixmap('alpha_back')))
         self.set_color(QColor(Qt.white))
 
         self.textEdited.connect(self._on_text_edited)
@@ -578,8 +589,8 @@ class Color2DSlider(QWidget, object):
 
     def _set_color_from_pos(self, pt, size):
         pt_float = QPointF(
-            mathlib.clamp(float(pt.x()) / size.width(), 0.0, 1.0),
-            mathlib.clamp(1 - float(pt.y()) / size.height(), 0.0, 1.0)
+            utils.clamp(float(pt.x()) / size.width(), 0.0, 1.0),
+            utils.clamp(1 - float(pt.y()) / size.height(), 0.0, 1.0)
         )
 
         if self._comp_x == self.Component.HUE:
@@ -710,23 +721,24 @@ class ColorWheel(QWidget, object):
             self.colorSelected.emit(self.color())
             self.colorChanged.emit(self.color())
             self.update()
+            return
         elif self._mouse_status == self.MouseStatus.DRAW_SQUARE:
             glob_mouse_ln = self._line_to_point(event.pos())
             center_mouse_ln = QLineF(QPointF(0, 0), glob_mouse_ln.p2() - glob_mouse_ln.p1())
             center_mouse_ln.setAngle(center_mouse_ln.angle() + self._selector_image_angle())
             center_mouse_ln.setP2(center_mouse_ln.p2() - self._selector_image_offset())
             if self._selector_shape == self.WheelShape.SQUARE:
-                self._sat = mathlib.clamp(center_mouse_ln.x2() / self._square_size(), 0.0, 1.0)
-                self._val = mathlib.clamp(center_mouse_ln.y2() / self._square_size(), 0.0, 1.0)
+                self._sat = utils.clamp(center_mouse_ln.x2() / self._square_size(), 0.0, 1.0)
+                self._val = utils.clamp(center_mouse_ln.y2() / self._square_size(), 0.0, 1.0)
             elif self._selector_shape == self.WheelShape.TRIANGLE:
                 pt = center_mouse_ln.p2()
                 side = self._triangle_side()
-                self._val = mathlib.clamp(pt.x() / self._triangle_height(), 0.0, 1.0)
+                self._val = utils.clamp(pt.x() / self._triangle_height(), 0.0, 1.0)
                 slice_h = side * self._val
                 y_center = side / 2
                 y_min = y_center - slice_h / 2
                 if slice_h > 0:
-                    self._sat = mathlib.clamp((pt.y() - y_min) / slice_h, 0.0, 1.0)
+                    self._sat = utils.clamp((pt.y() - y_min) / slice_h, 0.0, 1.0)
 
         self.colorSelected.emit(self.color())
         self.colorChanged.emit(self.color())
@@ -779,7 +791,7 @@ class ColorWheel(QWidget, object):
         return self._hue
 
     def set_hue(self, hue):
-        self._hue = mathlib.clamp(hue, 0.0, 1.0)
+        self._hue = utils.clamp(hue, 0.0, 1.0)
         self._render_inner_selector()
         self.update()
 
@@ -787,14 +799,14 @@ class ColorWheel(QWidget, object):
         return self.color().hsvSaturationF()
 
     def set_saturation(self, sat):
-        self._sat = mathlib.clamp(sat, 0.0, 1.0)
+        self._sat = utils.clamp(sat, 0.0, 1.0)
         self.update()
 
     def value(self):
         return self.color().valueF()
 
     def set_value(self, val):
-        self._val = mathlib.clamp(val, 0.0, 1.0)
+        self._val = utils.clamp(val, 0.0, 1.0)
         self.update()
 
     def color_space(self):
@@ -856,7 +868,7 @@ class ColorWheel(QWidget, object):
         self.wheelWidthChanged.emit(width)
 
     def _setup(self):
-        background_value = self.palette().background().color().valueF()
+        background_value = self.palette().window().color().valueF()
         self._background_is_dark = background_value < 0.5
 
     def _init_buffer(self, size):
@@ -874,6 +886,8 @@ class ColorWheel(QWidget, object):
         self._inner_selector = QImage(self._inner_selector_buffer, size.width(), size.height(), QImage.Format_RGB32)
 
     def _set_color(self, color):
+        if isinstance(color, (tuple, list)):
+            color = QColor(*color)
         if self._color_space == self.WheelColorSpace.COLOR_HSV:
             self._hue = max(0.0, color.hsvHueF())
             self._sat = color.hsvSaturationF()
@@ -994,7 +1008,7 @@ class ColorWheel(QWidget, object):
             slice_h = size.height() * point_val
             for y in range(init_size.height()):
                 y_min = y_center - slice_h / 2
-                point_sat = mathlib.clamp((y - y_min) / slice_h, 0.0, 1.0) if slice_h > 0 else 0
+                point_sat = utils.clamp((y - y_min) / slice_h, 0.0, 1.0) if slice_h > 0 else 0
                 color = self._color_from(self._hue, point_sat, point_val, 1).rgb()
                 self._inner_selector_buffer[init_size.width() * y + x] = color
 
@@ -1069,7 +1083,7 @@ class ColorPreview(QWidget, object):
         self._background = QBrush(Qt.darkGray, Qt.DiagCrossPattern)
         self._display_mode = self.DisplayMode.NO_ALPHA
 
-        self._background.setTexture(QPixmap(tp.ResourcesMgr().pixmap('alpha_back')))
+        self._background.setTexture(QPixmap(resources.pixmap('alpha_back')))
 
     def sizeHint(self):
         return QSize(24, 24)
@@ -1100,6 +1114,8 @@ class ColorPreview(QWidget, object):
         return self._col
 
     def set_color(self, color):
+        if isinstance(color, (tuple, list)):
+            color = QColor(*color)
         self._col = color
         self.update()
         self.colorChanged.emit(color)
@@ -1170,6 +1186,8 @@ class ColorSelector(ColorPreview, object):
     updateModeChanged = Signal(int)
     showModeChanged = Signal(int)
     dialogModalityChanged = Signal(Qt.WindowModality)
+    acceptedColor = Signal(object)
+    closedColor = Signal(object)
 
     class UpdateMode(object):
         CONFIRM = 0         # Update color only after the dialog has been accepted
@@ -1191,6 +1209,7 @@ class ColorSelector(ColorPreview, object):
         self._panel = None
         self._show_mode = None
         self._panel_parent = parent
+        self._reset_on_close = True
 
         self.set_update_mode(self.UpdateMode.CONTINUOUS)
         self.set_show_mode(self.ShowMode.PANEL)
@@ -1238,6 +1257,9 @@ class ColorSelector(ColorPreview, object):
         self._dialog_modality = modality
         self.dialogModalityChanged.emit(modality)
 
+    def set_reset_on_close(self, flag):
+        self._reset_on_close = flag
+
     def wheel_shape(self):
         return self._color_widget.wheel_shape()
 
@@ -1260,15 +1282,19 @@ class ColorSelector(ColorPreview, object):
         self._panel_parent = parent
 
     def show_panel(self):
+        self._color_widget._select_color_btn.setVisible(True)
+        self._color_widget._cancel_btn.setVisible(True)
         self._panel = panel.SliderPanel(
             'Select Color', parent=self._panel_parent or self.parent(), closable=True)
         self.set_update_mode(self.UpdateMode.CONTINUOUS)
         self._panel.set_widget(self._color_widget)
-        self._panel.closeButtonClicked.connect(self._on_close_panel)
+        self._panel.closed.connect(self._on_close_panel)
         self._connect_panel()
         self._panel.show()
 
     def show_dialog(self):
+        self._color_widget._select_color_btn.setVisible(False)
+        self._color_widget._cancel_btn.setVisible(False)
         self._dialog = ColorDialog(color_widget=self._color_widget, parent=self)
         if self._dialog_modality:
             self._dialog.setWindowModality(self._dialog_modality)
@@ -1280,13 +1306,18 @@ class ColorSelector(ColorPreview, object):
         self._dialog.exec_()
 
     def _connect_panel(self):
+        self._color_widget.colorSelected.connect(self._on_selected_panel_color)
+        self._color_widget.colorCancelled.connect(self._panel.close)
         if self._update_mode == self.UpdateMode.CONTINUOUS:
             self._color_widget.colorChanged.connect(self.set_color)
         else:
             self._disconnect_panel()
 
     def _disconnect_panel(self):
-        self._color_widget.disconnect(self.set_color)
+        self._color_widget.colorSelected.disconnect(self._on_selected_panel_color)
+        self._color_widget.colorCancelled.disconnect(self._panel.close)
+        if self._update_mode == self.UpdateMode.CONTINUOUS:
+            self._color_widget.colorChanged.disconnect(self.set_color)
 
     def _disconnect_dialog(self, dialog):
         dialog.colorChanged.disconnect(self.set_color)
@@ -1305,15 +1336,28 @@ class ColorSelector(ColorPreview, object):
         if (self._dialog and not self._dialog.isVisible()) or (self._panel and not self._panel.isVisible()):
             self._old_color = color
 
+    def _on_selected_panel_color(self, color):
+        self.set_color(color)
+        self._panel.blockSignals(True)
+        try:
+            self._panel.close()
+        finally:
+            self._panel.blockSignals(False)
+        self.acceptedColor.emit(self.color())
+        self._disconnect_panel()
+
     def _on_close_panel(self):
-        self.set_color(self._old_color)
-        self._color_widget.set_color(self._old_color)
-        self._panel = None
+        if self._reset_on_close:
+            self.set_color(self._old_color)
+            self._color_widget.set_color(self._old_color)
+        self.closedColor.emit(self.color())
+        self._disconnect_panel()
 
     def _on_accepted_dialog(self):
         self.set_color(self._dialog.color())
         self._old_color = self.color()
         self._dialog = None
+        self.acceptedColor.emit(self.color())
 
     def _on_rejected_dialog(self):
         self.set_color(self._old_color)
@@ -1341,7 +1385,7 @@ class GradientSlider(QSlider, object):
 
         self._gradient = QLinearGradient()
         self._background = QBrush(Qt.darkGray, Qt.DiagCrossPattern)
-        self._background.setTexture(QPixmap(tp.ResourcesMgr().pixmap('alpha_back')))
+        self._background.setTexture(QPixmap(resources.pixmap('alpha_back')))
         self._gradient.setCoordinateMode(QGradient.StretchToDeviceMode)
         self._gradient.setSpread(QGradient.RepeatSpread)
 
@@ -1545,7 +1589,7 @@ class HueSlider(GradientSlider, object):
         return self._saturation
 
     def set_color_saturation(self, saturation):
-        self._saturation = mathlib.clamp(saturation, 0.0, 1.0)
+        self._saturation = utils.clamp(saturation, 0.0, 1.0)
         self._update_gradient()
         self.colorSaturationChanged.emit(saturation)
 
@@ -1553,7 +1597,7 @@ class HueSlider(GradientSlider, object):
         return self._value
 
     def set_color_value(self, value):
-        self._value = mathlib.clamp(value, 0.0, 1.0)
+        self._value = utils.clamp(value, 0.0, 1.0)
         self._update_gradient()
         self.colorValueChanged.emit(value)
 
@@ -1600,6 +1644,7 @@ class ColorDialogWidget(base.BaseWidget, object):
 
     colorSelected = Signal(QColor)
     colorChanged = Signal(QColor)
+    colorCancelled = Signal()
     alphaEnabledChanged = Signal(bool)
     colorSpaceChanged = Signal(int)
     rotatingSelectorChanged = Signal(bool)
@@ -1607,6 +1652,7 @@ class ColorDialogWidget(base.BaseWidget, object):
 
     def __init__(self, parent=None):
         self._color = QColor()
+        self._color_list = (0, 0, 0, 255)
         self._alpha_enabled = False
         self._pick_from_screen = False
 
@@ -1615,34 +1661,28 @@ class ColorDialogWidget(base.BaseWidget, object):
         self.setAcceptDrops(True)
         self.set_alpha_enabled(True)
 
+    # =================================================================================================================
+    # OVERRIDES
+    # =================================================================================================================
+
     def get_main_layout(self):
-        main_layout = QVBoxLayout()
-        main_layout.setContentsMargins(0, 0, 0, 0)
-        main_layout.setSpacing(2)
+        main_layout = layouts.VerticalLayout(spacing=2, margins=(0, 0, 0, 0,))
 
         return main_layout
 
     def ui(self):
         super(ColorDialogWidget, self).ui()
 
-        horizontal_lyt = QHBoxLayout()
-        horizontal_lyt.setContentsMargins(0, 0, 0, 0)
-        horizontal_lyt.setSpacing(2)
-
-        preview_wheel_lyt = QVBoxLayout()
-        preview_wheel_lyt.setContentsMargins(0, 0, 0, 0)
-        preview_wheel_lyt.setSpacing(7)
-
-        self._buttons_lyt = QHBoxLayout()
-        self._buttons_lyt.setContentsMargins(0, 0, 0, 0)
-        self._buttons_lyt.setSpacing(2)
+        horizontal_lyt = layouts.HorizontalLayout(spacing=2, margins=(0, 0, 0, 0,))
+        preview_wheel_lyt = layouts.VerticalLayout(spacing=2, margins=(0, 0, 0, 0,))
+        self._buttons_lyt = layouts.HorizontalLayout(spacing=2, margins=(0, 0, 0, 0,))
 
         self._color_wheel = ColorWheel()
         self._color_preview = ColorPreview()
         preview_wheel_lyt.addWidget(self._color_wheel)
         preview_wheel_lyt.addWidget(self._color_preview)
 
-        colors_lyt = QGridLayout()
+        colors_lyt = layouts.GridLayout()
         hue_lbl = label.BaseLabel('Hue')
         self._hue_slider = HueSlider()
         self._hue_spinner = spinbox.BaseSpinBox()
@@ -1711,9 +1751,18 @@ class ColorDialogWidget(base.BaseWidget, object):
         self._buttons_lyt.addWidget(self._pick_btn)
         self._buttons_lyt.addStretch()
 
+        bottom_layout = layouts.HorizontalLayout(spacing=1, margins=(0, 0, 0, 0))
+        self._select_color_btn = buttons.BaseButton('Select', resources.icon('palette'), parent=self)
+        self._cancel_btn = buttons.BaseButton('Cancel', resources.icon('cancel'), parent=self)
+        bottom_layout.addStretch()
+        bottom_layout.addWidget(self._select_color_btn)
+        bottom_layout.addWidget(self._cancel_btn)
+
         self.main_layout.addLayout(horizontal_lyt)
         self.main_layout.addWidget(dividers.Divider())
         self.main_layout.addLayout(self._buttons_lyt)
+        self.main_layout.addStretch()
+        self.main_layout.addLayout(bottom_layout)
 
     def setup_signals(self):
         self._color_wheel.colorSpaceChanged.connect(self.colorSpaceChanged.emit)
@@ -1732,9 +1781,11 @@ class ColorDialogWidget(base.BaseWidget, object):
         self._value_slider.valueChanged.connect(self.set_hsv)
         self._value_slider.valueChanged.connect(self._value_spinner.setValue)
         self._saturation_slider.valueChanged.connect(self.set_hsv)
-        self._saturation_slider.valueChanged.connect(self._saturation_spinner.setValue)
+        # TODO: Check why this was causing crash when moving saturation slider
+        # self._saturation_slider.valueChanged.connect(self._saturation_spinner.setValue)
         self._hue_slider.valueChanged.connect(self.set_hsv)
-        self._hue_slider.valueChanged.connect(self._hue_spinner.setValue)
+        # TODO: Check why this was causing crash when moving hue slider
+        # self._hue_slider.valueChanged.connect(self._hue_spinner.setValue)
         self._red_slider.valueChanged.connect(self.set_rgb)
         self._red_slider.valueChanged.connect(self._red_spinner.setValue)
         self._green_slider.valueChanged.connect(self.set_rgb)
@@ -1750,6 +1801,15 @@ class ColorDialogWidget(base.BaseWidget, object):
         self._pick_btn.clicked.connect(self._on_grab_color)
         self._reset_btn.clicked.connect(self._on_reset)
 
+        self._select_color_btn.clicked.connect(self._on_select_color)
+        self._cancel_btn.clicked.connect(self.colorCancelled.emit)
+
+    def enable_select_cancel_buttons(self, flag):
+        self._cancel_btn.setVisible(flag)
+        self._cancel_btn.setEnabled(flag)
+        self._select_color_btn.setVisible(flag)
+        self._select_color_btn.setEnabled(flag)
+
     def dragEnterEvent(self, event):
         if event.mimeData().hasColor() or (event.mimeData().hasText() and QColor(event.mimeData().text()).isValid()):
             event.acceptProposedAction()
@@ -1774,7 +1834,11 @@ class ColorDialogWidget(base.BaseWidget, object):
             self._pick_from_screen = False
             self.releaseMouse()
 
-    def color(self):
+    # =================================================================================================================
+    # BASE
+    # =================================================================================================================
+
+    def get_color(self):
         col = self._color
         if not self._alpha_enabled:
             col.setAlpha(255)
@@ -1786,6 +1850,24 @@ class ColorDialogWidget(base.BaseWidget, object):
         self._hex_line.setModified(False)
         self._set_color(color)
 
+    def get_color_list(self):
+        return self._color_list
+
+    def set_color_list(self, color_list):
+        self._color_list = color_list
+        self.blockSignals(True)
+        widgets = self.findChildren(QWidget)
+        for widget in widgets:
+            widget.blockSignals(True)
+        try:
+            self.set_color(QColor(*color_list))
+        finally:
+            self.blockSignals(False)
+            for widget in widgets:
+                widget.blockSignals(False)
+
+    colorList = Property(tuple, get_color_list, set_color_list, user=True)
+
     def comparison_color(self):
         return self._color_preview.comparison_color()
 
@@ -1809,6 +1891,10 @@ class ColorDialogWidget(base.BaseWidget, object):
         self._alpha_slider.setVisible(flag)
         self._alpha_spinner.setVisible(flag)
         self.alphaEnabledChanged.emit(flag)
+        if flag:
+            self._color_preview.set_display_mode(ColorPreview.DisplayMode.SPLIT_ALPHA)
+        else:
+            self._color_preview.set_display_mode(ColorPreview.DisplayMode.NO_ALPHA)
 
     def set_hsv(self):
         if not self.signalsBlocked():
@@ -1854,8 +1940,15 @@ class ColorDialogWidget(base.BaseWidget, object):
         self._color_wheel.set_rotating_selector(flag)
 
     def _set_color(self, color):
-        self._color_wheel.set_color(color)
+
+        if isinstance(color, (tuple, list)):
+            color = QColor(*color)
+        alpha = self._color.alphaF()
         self._color = color
+        self._color_list = color.red(), color.green(), color.blue(), color.alpha()
+
+        self._color_wheel.set_color(color)
+
         blocked = self.signalsBlocked()
         self.blockSignals(True)
         for widget in self.findChildren(QWidget):
@@ -1891,13 +1984,14 @@ class ColorDialogWidget(base.BaseWidget, object):
         self._value_slider.set_first_color(QColor.fromHsvF(self._color_wheel.hue(), self._color_wheel.saturation(), 0))
         self._value_slider.set_last_color(QColor.fromHsvF(self._color_wheel.hue(), self._color_wheel.saturation(), 1))
 
-        alpha_color = color
+        color.setAlphaF(alpha)
+        alpha_color = QColor(color)
         alpha_color.setAlpha(0)
         self._alpha_slider.set_first_color(alpha_color)
         alpha_color.setAlpha(255)
         self._alpha_slider.set_last_color(alpha_color)
         self._alpha_spinner.setValue(color.alpha())
-        # self._alpha_slider.setValue(color.alpha())
+        self._alpha_slider.setValue(color.alpha())
         if not self._hex_line.isModified():
             self._hex_line.set_color(color)
         self._color_preview.set_color(color)
@@ -1908,6 +2002,10 @@ class ColorDialogWidget(base.BaseWidget, object):
 
         self.colorChanged.emit(color)
 
+    # =================================================================================================================
+    # CALLBACKS
+    # =================================================================================================================
+
     def _on_edit_hex_color_changed(self, color):
         self._set_color(color)
 
@@ -1922,6 +2020,10 @@ class ColorDialogWidget(base.BaseWidget, object):
     def _on_reset(self):
         self._set_color(self._color_preview.comparison_color())
 
+    def _on_select_color(self):
+        current_color = self.get_color()
+        self.colorSelected.emit(current_color)
+
 
 class ColorDialog(QDialog, object):
 
@@ -1936,16 +2038,17 @@ class ColorDialog(QDialog, object):
     def __init__(self, color_widget=None, parent=None):
         super(ColorDialog, self).__init__(parent)
 
+        self.setWindowTitle('Color Selector')
+
         self._button_mode = self.ButtonMode.OK_CANCEL
 
-        main_layout = QVBoxLayout()
-        main_layout.setContentsMargins(0, 0, 0, 0)
-        main_layout.setSpacing(2)
+        main_layout = layouts.VerticalLayout(spacing=2, margins=(0, 0, 0, 0))
         self.setLayout(main_layout)
 
         self._color_widget = color_widget or ColorDialogWidget()
         self._color_widget.colorChanged.connect(self.colorChanged.emit)
         self._color_widget.colorSelected.connect(self.colorSelected.emit)
+        self._color_widget.enable_select_cancel_buttons(False)
 
         self._button_box = QDialogButtonBox()
         self._button_box.setStandardButtons(
@@ -1962,7 +2065,7 @@ class ColorDialog(QDialog, object):
     #     return QSize(400, 0)
 
     def color(self):
-        return self._color_widget.color()
+        return self._color_widget.get_color()
 
     def set_color(self, color):
         self._color_widget.set_color(color)
@@ -2002,5 +2105,276 @@ class ColorDialog(QDialog, object):
     def _on_button_box_clicked(self, btn):
         role = self._button_box.buttonRole(btn)
         if role == QDialogButtonBox.AcceptRole or role == QDialogButtonBox.ApplyRole:
-            self._color_widget._color_preview.set_comparison_color(self._color_widget.color())
-            self._color_widget.colorSelected.emit(self._color_widget.color())
+            self._color_widget._color_preview.set_comparison_color(self._color_widget.get_color())
+            self._color_widget.colorSelected.emit(self._color_widget.get_color())
+
+
+class ColorRgbGradientSlider(sliders.DoubleSlider, object):
+    """
+    Custom slider to select a color by non editable gradient
+    """
+
+    def __init__(self, parent, color1=None, color2=None, slider_range=None, dragger_steps=None, main_color=None, *args):
+        if color1 is None:
+            color1 = [0, 0, 0]
+        if color2 is None:
+            color2 = [255, 255, 255]
+        if slider_range is None:
+            slider_range = (0.0, 255.0)
+        if dragger_steps is None:
+            dragger_steps = [5.0, 1.0, 0.25]
+        super(ColorRgbGradientSlider, self).__init__(
+            parent=parent, slider_range=slider_range, dragger_steps=dragger_steps, *args)
+
+        self._parent = parent
+        self._color1 = QColor(color1[0], color1[1], color1[2])
+        self._color2 = QColor(color2[0], color2[1], color2[2])
+        self._main_color = main_color if main_color else QColor(215, 128, 26).getRgb()
+
+        self.setStyleSheet(self._get_style_sheet())
+
+    def paintEvent(self, event):
+        painter = QPainter()
+        painter.begin(self)
+        self._draw_widget(painter)
+        painter.end()
+        super(ColorRgbGradientSlider, self).paintEvent(event)
+
+    def get_color(self):
+        """
+        Computes and returns current color
+        :return: list(float, float, float)
+        """
+
+        r1, g1, b1 = self._color1.getRgb()
+        r2, g2, b2 = self._color2.getRgb()
+        f_r = (r2 - r1) * self.mapped_value() + r1
+        f_g = (g2 - g1) * self.mapped_value() + g1
+        f_b = (b2 - b1) * self.mapped_value() + b1
+
+        return [f_r, f_g, f_b]
+
+    def _draw_widget(self, painter):
+        width = self.width()
+        height = self.height()
+
+        gradient = QLinearGradient(0, 0, width, height)
+        gradient.setColorAt(0, self._color1)
+        gradient.setColorAt(1, self._color2)
+        painter.setBrush(QBrush(gradient))
+
+        painter.drawRect(0, 0, width, height)
+
+    def _get_style_sheet(self):
+        return """
+        QSlider,QSlider:disabled,QSlider:focus{
+                                  background: qcolor(0,0,0,0);   }
+
+         QSlider::groove:horizontal {
+            border: 1px solid #999999;
+            background: qcolor(0,0,0,0);
+         }
+        QSlider::handle:horizontal {
+            background:  rgba(255, 255, 255, 150);
+            width: 10px;
+            border-radius: 4px;
+            border: 1.5px solid black;
+         }
+         QSlider::handle:horizontal:hover {
+            border: 2.25px solid %s;
+         }
+        """ % "rgba%s" % str(self._main_color)
+
+
+class ColorRgbSliders(base.BaseWidget, object):
+    """
+    Custom slider to choose a color by its components
+    """
+
+    colorChanged = Signal(tuple)
+
+    def __init__(self, parent=None, start_color=None, slider_type='float', alpha=False, height=50, *args):
+
+        self._parent = parent
+        self._type = slider_type
+        self._alpha = alpha
+        self._default_color = start_color or 0, 0, 0, 255
+        self._height = height
+        self._color = self._default_color
+        self._style_str = "QPushButton{ background-color: rgba(%f,%f,%f,%f);border-color: black;" \
+                          "border-radius: 2px;border-style: outset;border-width: 1px;}" \
+                          "\nQPushButton:pressed{ border-style: inset;border-color: beige}"
+
+        super(ColorRgbSliders, self).__init__(parent=parent, *args)
+
+    def _get_color(self):
+        return self._color
+
+    def _set_color(self, color_tuple):
+        self._color = color_tuple
+        with qt_contexts.block_signals(self):
+            self._red_slider.set_mapped_value(self._color[0], block_signals=True)
+            self._green_slider.set_mapped_value(self._color[1], block_signals=True)
+            self._blue_slider.set_mapped_value(self._color[2], block_signals=True)
+            try:
+                self._alpha_slider.set_mapped_value(self._color[3], block_signals=True)
+            except Exception:
+                pass
+
+    color = Property(tuple, _get_color, _set_color)
+
+    def get_main_layout(self):
+        return layouts.HorizontalLayout(spacing=5)
+
+    def ui(self):
+        super(ColorRgbSliders, self).ui()
+
+        self.setMaximumHeight(self._height)
+
+        self._menu = QMenu(self)
+        self._action_reset = self._menu.addAction('Reset Value')
+
+        self._red_dragger = sliders.DraggerSlider(slider_type=self._type)
+        self._green_dragger = sliders.DraggerSlider(slider_type=self._type)
+        self._blue_dragger = sliders.DraggerSlider(slider_type=self._type)
+        self._alpha_dragger = sliders.DraggerSlider(slider_type=self._type)
+        for dragger in [self._red_dragger, self._green_dragger, self._blue_dragger, self._alpha_dragger]:
+            dragger.setMinimum(0)
+            if self._type == 'int':
+                dragger.setMaximum(255)
+            else:
+                dragger.setMaximum(1.0)
+
+        self._red_slider = ColorRgbGradientSlider(parent=self, color2=[255, 0, 0])
+        self._green_slider = ColorRgbGradientSlider(parent=self, color2=[0, 255, 0])
+        self._blue_slider = ColorRgbGradientSlider(parent=self, color2=[0, 0, 255])
+        self._alpha_slider = ColorRgbGradientSlider(parent=self, color2=[255, 255, 255])
+
+        self._red_dragger.valueChanged.connect(lambda value: self._red_slider.set_mapped_value(float(value)))
+        self._red_slider.doubleValueChanged.connect(lambda value: self._red_dragger.setValue(value))
+        self._green_dragger.valueChanged.connect(lambda value: self._green_slider.set_mapped_value(float(value)))
+        self._green_slider.doubleValueChanged.connect(lambda value: self._green_dragger.setValue(value))
+        self._blue_dragger.valueChanged.connect(lambda value: self._blue_slider.set_mapped_value(float(value)))
+        self._blue_slider.doubleValueChanged.connect(lambda value: self._blue_dragger.setValue(value))
+        self._alpha_dragger.valueChanged.connect(lambda value: self._alpha_slider.set_mapped_value(float(value)))
+        self._alpha_slider.doubleValueChanged.connect(lambda value: self._alpha_dragger.setValue(value))
+
+        red_layout = layouts.HorizontalLayout()
+        green_layout = layouts.HorizontalLayout()
+        blue_layout = layouts.HorizontalLayout()
+        alpha_layout = layouts.HorizontalLayout()
+        red_layout.addWidget(self._red_dragger)
+        red_layout.addWidget(self._red_slider)
+        green_layout.addWidget(self._green_dragger)
+        green_layout.addWidget(self._green_slider)
+        blue_layout.addWidget(self._blue_dragger)
+        blue_layout.addWidget(self._blue_slider)
+        alpha_layout.addWidget(self._alpha_dragger)
+        alpha_layout.addWidget(self._alpha_slider)
+        self._sliders_layout = layouts.VerticalLayout()
+        self._sliders_layout.setSpacing(0)
+        layouts_list = [red_layout, green_layout, blue_layout]
+        if self._alpha:
+            layouts_list.append(alpha_layout)
+        else:
+            self._alpha_slider.hide()
+
+        self._alpha_slider.set_mapped_value(255)
+
+        self._color_btn = buttons.BaseButton(parent=self)
+        self._color_btn.setMaximumWidth(self._height)
+        self._color_btn.setMinimumWidth(self._height)
+        self._color_btn.setMaximumHeight(self._height - 12)
+        self._color_btn.setMinimumHeight(self._height - 12)
+        self._color_btn.setStyleSheet(
+            self._style_str % (
+                self._red_slider.mapped_value(), self._green_slider.mapped_value(),
+                self._blue_slider.mapped_value(), self._alpha_slider.mapped_value()))
+
+        for widget in [self._red_slider, self._green_slider, self._blue_slider, self._alpha_slider,
+                       self._red_dragger, self._green_dragger, self._blue_dragger, self._alpha_dragger]:
+            widget.setMaximumHeight(self._height / len(layouts_list) + 1)
+            widget.setMinimumHeight(self._height / len(layouts_list) + 1)
+
+        for slider in [self._red_slider, self._green_slider, self._blue_slider, self._alpha_slider]:
+            slider.doubleValueChanged.connect(self._on_color_changed)
+
+        for layout in layouts_list:
+            self._sliders_layout.addLayout(layout)
+
+        self.main_layout.addWidget(self._color_btn)
+        self.main_layout.addLayout(self._sliders_layout)
+
+        if isinstance(self._default_color, list) and len(self._default_color) >= 3:
+            self.set_color(self._default_color)
+
+        self._color_btn.clicked.connect(self._on_show_color_dialog)
+        self._action_reset.triggered.connect(self._on_reset_value)
+
+    def contextMenuEvent(self, event):
+        self._menu.exec_(event.globalPos())
+
+    def set_color(self, new_color):
+        self._red_slider.set_mapped_value(new_color[0])
+        self._green_slider.set_mapped_value(new_color[1])
+        self._green_slider.set_mapped_value(new_color[2])
+        if len(new_color) > 3:
+            self._alpha_slider.set_mapped_value(new_color[3])
+
+    def _on_color_changed(self):
+        self._color_btn.setStyleSheet(
+            self._style_str % (
+                self._red_slider.mapped_value(), self._green_slider.mapped_value(),
+                self._blue_slider.mapped_value(), self._alpha_slider.mapped_value()))
+        value_list = [
+            self._red_slider.mapped_value(), self._green_slider.mapped_value(), self._blue_slider.mapped_value()]
+        if self._alpha:
+            value_list.append(self._alpha_slider.mapped_value())
+        if self._type == 'int':
+            value_list = [utils.clamp(int(i), 0, 255) for i in value_list]
+        self._color = python.force_tuple(value_list)
+        self.colorChanged.emit(self._color)
+
+    def _on_show_color_dialog(self):
+        if self._alpha:
+            new_color = QColorDialog.getColor(options=QColorDialog.ShowAlphaChannel)
+        else:
+            new_color = QColorDialog.getColor()
+        if new_color.isValid():
+            self._red_slider.set_mapped_value(
+                utils.map_range_unclamped(
+                    new_color.redF(), 0.0, 1.0, self._red_slider.slider_range[0], self._red_slider.slider_range[1]))
+            self._green_slider.set_mapped_value(
+                utils.map_range_unclamped(
+                    new_color.greenF(), 0.0, 1.0, self._green_slider.slider_range[0],
+                    self._green_slider.slider_range[1]))
+            self._blue_slider.set_mapped_value(
+                utils.map_range_unclamped(
+                    new_color.blueF(), 0.0, 1.0, self._blue_slider.slider_range[0], self._blue_slider.slider_range[1]))
+            self._alpha_slider.set_mapped_value(
+                utils.map_range_unclamped(
+                    new_color.alphaF(), 0.0, 1.0, self._alpha_slider.slider_range[0],
+                    self._alpha_slider.slider_range[1]))
+
+    def _on_reset_value(self):
+        if self._default_color:
+            self.set_color(self._default_color)
+
+
+class ColorPaletteWidget(base.BaseWidget):
+    def __init__(self, draggable=True, parent=None):
+
+        self._draggable = draggable
+        self._pressed = None
+        self._drag_color = QColor()
+        self._prev_button = None
+
+        super(ColorPaletteWidget, self).__init__(parent=parent)
+
+        self._fill_default_color_list()
+
+    def ui(self):
+        super(ColorPaletteWidget, self).ui()
+
+    def _fill_default_color_list(self):
+        pass
