@@ -8,16 +8,19 @@ Module that contains widgets related with directories and files
 from __future__ import print_function, division, absolute_import
 
 import os
+import logging
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
-from Qt.QtGui import *
+from tpDcc import dcc
+from Qt.QtCore import Qt, Signal
+from Qt.QtWidgets import QSizePolicy, QWidget, QListWidget, QAbstractItemView
+from Qt.QtGui import QColor, QPalette
 
-import tpDcc as tp
-from tpDcc.libs import qt
+from tpDcc.managers import resources
 from tpDcc.libs.python import path
 from tpDcc.libs.qt.core import base, qtutils
-from tpDcc.libs.qt.widgets import buttons
+from tpDcc.libs.qt.widgets import layouts, buttons, lineedit, label
+
+LOGGER = logging.getLogger('tpDcc-libs-qt')
 
 
 class FileListWidget(QListWidget, object):
@@ -38,12 +41,9 @@ class FileListWidget(QListWidget, object):
         self.parent = parent
         super(FileListWidget, self).__init__(parent)
 
-        # region Signals
         self.itemSelectionChanged.connect(self.selectItem)
         self.itemDoubleClicked.connect(self.activateItem)
-        # endregion
 
-    # region Override Functions
     def resizeEvent(self, event):
         """
         Overrides QWidget resizeEvent so when the widget is resize a update request signal is emitted
@@ -86,9 +86,7 @@ class FileListWidget(QListWidget, object):
             self.update_requested.emit()
         else:
             super(FileListWidget, self).keyPressEvent(event)
-    # endregion
 
-    # region Public Functions
     def selectItem(self):
         if len(self.selectedItems()) > 0:
             item = self.selectedItems()[0]
@@ -118,10 +116,9 @@ class FileListWidget(QListWidget, object):
         items = filter(lambda x: x.type() != 0, self.selectedItems())
         names = map(lambda x: x.text(), items)
         self.files_selected.emit(names)
-    # endregion
 
 
-class FolderEditLine(QLineEdit, object):
+class FolderEditLine(lineedit.BaseLineEdit, object):
     """
     Custom QLineEdit with drag and drop behaviour for files and folders
     """
@@ -171,19 +168,16 @@ class SelectFolderButton(QWidget, object):
         self._directory = directory
         self.settings = None
 
-        main_layout = QHBoxLayout()
-        main_layout.setContentsMargins(2, 2, 2, 2)
-        main_layout.setSpacing(2)
+        main_layout = layouts.HorizontalLayout(spacing=2, margins=(2, 2, 2, 2))
         self.setLayout(main_layout)
 
-        folder_icon = tp.ResourcesMgr().icon('folder')
-        self._folder_btn = buttons.IconButton(
-            icon=folder_icon, icon_padding=2, button_style=buttons.ButtonStyles.FlatStyle)
+        folder_icon = resources.icon('folder')
+        self._folder_btn = buttons.BaseButton(text, parent=self)
+        self._folder_btn.setIcon(folder_icon)
         main_layout.addWidget(self._folder_btn)
 
         self._folder_btn.clicked.connect(self._open_folder_browser_dialog)
 
-    # region Properties
     @property
     def folder_btn(self):
         return self._folder_btn
@@ -195,14 +189,10 @@ class SelectFolderButton(QWidget, object):
         self._directory = directory
 
     init_directory = property(get_init_directory, set_init_directory)
-    # endregion
 
-    # region Public Functions
     def set_settings(self, settings):
         self.settings = settings
-    # endregion
 
-    # region Private Functions
     def _open_folder_browser_dialog(self):
         """
         Opens a set folder browser and returns the selected path
@@ -211,23 +201,13 @@ class SelectFolderButton(QWidget, object):
 
         self.beforeNewDirectory.emit()
 
-        if tp.Dcc.get_name() == tp.Dccs.Maya:
-            import maya.cmds as cmds
-            result = cmds.fileDialog2(caption='Select Folder', fileMode=3, startingDirectory=self.init_directory)
-            if result:
-                result = result[0]
-            else:
-                return
-        else:
-            raise NotImplementedError(
-                'Open Folder Browser Dialog is not impelented in your current DCC: {}'.format(tp.Dcc.get_name()))
+        result = dcc.select_folder_dialog('Select Folder', start_directory=self.init_directory) or ''
 
         self.directoryChanged.emit(result)
         # if not result or not os.path.isdir(result[0]):
         if not result or not os.path.isdir(result):
             return
         return path.clean_path(result[0])
-    # endregion
 
 
 class SelectFolder(QWidget, object):
@@ -247,25 +227,25 @@ class SelectFolder(QWidget, object):
         self._label_text = label_text
         self._directory = directory
 
-        main_layout = QHBoxLayout()
-        main_layout.setContentsMargins(2, 2, 2, 2)
-        main_layout.setSpacing(2)
+        main_layout = layouts.HorizontalLayout(spacing=2, margins=(2, 2, 2, 2))
         self.setLayout(main_layout)
 
-        self._folder_label = QLabel(
-            '{0}'.format(self._label_text)) if self._label_text == '' else QLabel('{0}:'.format(self._label_text))
+        self._folder_label = label.BaseLabel(
+            '{0}'.format(self._label_text)) if self._label_text == '' else label.BaseLabel(
+            '{0}:'.format(self._label_text))
+        if not self._label_text:
+            self._folder_label.setVisible(False)
         self._folder_line = FolderEditLine()
         self._folder_line.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
         if os.path.exists(self._directory):
             self._folder_line.setText(self._directory)
 
+        self._folder_btn = buttons.BaseButton(parent=self)
         if self._use_icon:
-            folder_icon = tp.ResourcesMgr().icon('folder')
-            self._folder_btn = buttons.IconButton(
-                icon=folder_icon, icon_padding=2, button_style=buttons.ButtonStyles.FlatStyle)
+            folder_icon = resources.icon('folder')
+            self._folder_btn.setIcon(folder_icon)
         else:
-            self._folder_btn = buttons.StyleBaseButton('Browse...')
-        self._folder_btn.setMaximumHeight(20)
+            self._folder_btn.setText('Browse ...')
 
         for widget in [self._folder_label, self._folder_line, self._folder_btn]:
             main_layout.addWidget(widget)
@@ -318,21 +298,13 @@ class SelectFolder(QWidget, object):
         :return: str, Path of the selected folder
         """
 
-        if tp.is_maya():
-            import tpDcc.dccs.maya as maya
-            result = maya.cmds.fileDialog2(
-                caption='Select Folder', fileMode=3, startingDirectory=self.folder_line.text())
-            if result:
-                result = result[0]
-            if not result or not os.path.isdir(result):
-                return
-            else:
-                filename = path.clean_path(result)
-                self.set_directory(filename)
-                self._text_changed()
+        result = dcc.select_folder_dialog('Select Folder', start_directory=self.folder_line.text()) or ''
+        if not result or not os.path.isdir(result):
+            return
         else:
-            raise NotImplementedError(
-                'Open Folder Browser Dialog is not implemented in your current DCC: {}'.format(tp.Dcc.get_name()))
+            filename = path.clean_path(result)
+            self.set_directory(filename)
+            self._text_changed()
 
         return filename
 
@@ -389,34 +361,37 @@ class SelectFile(base.DirectoryWidget, object):
         return self._folder_btn
 
     def get_main_layout(self):
-        main_layout = QHBoxLayout()
-        main_layout.setContentsMargins(2, 2, 2, 2)
-        main_layout.setSpacing(2)
-
+        main_layout = layouts.HorizontalLayout(spacing=2, margins=(2, 2, 2, 2))
         return main_layout
 
     def ui(self):
         super(SelectFile, self).ui()
 
-        self._file_label = QLabel('{0}'.format(self._label_text)) if self._label_text == '' else QLabel(
-            '{0}:'.format(self._label_text))
+        self._file_label = label.BaseLabel(
+            '{0}'.format(self._label_text)) if self._label_text == '' else label.BaseLabel(
+            '{0}:'.format(self._label_text), parent=self)
+        if not self._label_text:
+            self._file_label.setVisible(False)
         self._file_line = FolderEditLine()
         self._file_line.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
         if self._directory and os.path.exists(self._directory):
             self._file_line.setText(self._directory)
 
+        self._file_btn = buttons.BaseButton(parent=self)
+        self._clear_btn = buttons.BaseButton(parent=self)
         if self._use_icon:
-            folder_icon = tp.ResourcesMgr().icon('folder')
-            self._file_btn = buttons.IconButton(
-                icon=folder_icon, icon_padding=2, button_style=buttons.ButtonStyles.FlatStyle)
+            self._file_btn.setIcon(resources.icon('folder'))
+            self._clear_btn.setIcon(resources.icon('delete'))
         else:
-            self._file_btn = buttons.StyleBaseButton('Browse ...')
+            self._file_btn.setText('Browse ...')
+            self._clear_btn.setText('Clear')
 
-        for widget in [self._file_label, self._file_line, self._file_btn]:
+        for widget in [self._file_label, self._file_line, self._file_btn, self._clear_btn]:
             self.main_layout.addWidget(widget)
 
     def setup_signals(self):
         self._file_btn.clicked.connect(self._open_file_browser_dialog)
+        self._clear_btn.clicked.connect(self._on_reset_path)
         self._file_line.textChanged.connect(self._text_changed)
 
     def set_settings(self, settings):
@@ -443,6 +418,7 @@ class SelectFile(base.DirectoryWidget, object):
         """
 
         self._file_label.setText(text)
+        self._file_label.setVisible(bool(text))
 
     def set_directory(self, directory):
         """
@@ -468,30 +444,26 @@ class SelectFile(base.DirectoryWidget, object):
         :return: str, Path of the selected folder
         """
 
-        if tp.is_maya():
-            import tpDcc.dccs.maya as maya
-
-            file_line = self._file_line.text()
-            if os.path.isfile(file_line):
-                file_line = os.path.dirname(file_line)
-            result = maya.cmds.fileDialog2(
-                caption='Select File', fileMode=1, fileFilter=self._filters or '', startingDirectory=file_line)
-            if result:
-                result = result[0]
-            if not result or not os.path.isfile(result):
-                qt.logger.warning('Selected file {} is not a valid file!'.format(result))
-                return
-            else:
-                filename = path.clean_path(result)
-                self._file_line.setText(filename)
-                self.directoryChanged.emit(filename)
-                self.update_settings(filename=filename)
+        file_line = self._file_line.text()
+        if os.path.isfile(file_line):
+            file_line = os.path.dirname(file_line)
+        result = dcc.select_file_dialog('Select File', start_directory=file_line, pattern=self._filters or '') or ''
+        if not result or not os.path.isfile(result):
+            LOGGER.warning('Selected file "{}" is not a valid file!'.format(result))
+            return
         else:
-            raise NotImplementedError(
-                'Select File Dialog is not implemented in your current DCC: {}'.format(tp.Dcc.get_name()))
+            filename = path.clean_path(result)
+            self.set_directory(filename)
+            self.directoryChanged.emit(filename)
+            self.update_settings(filename=filename)
 
         return filename
 
+    def _on_reset_path(self):
+        self.set_directory('')
+        self.directoryChanged.emit('')
+        self.update_settings(filename='')
+
     def _text_changed(self):
         """
         This function is called each time the user manually changes the line text
@@ -522,16 +494,16 @@ class GetDirectoryWidget(base.DirectoryWidget, object):
         super(GetDirectoryWidget, self).ui()
 
         self._directory_widget = QWidget()
-        directory_layout = QHBoxLayout()
+        directory_layout = layouts.HorizontalLayout()
         self._directory_widget.setLayout(directory_layout)
         self.main_layout.addWidget(self._directory_widget)
 
-        self._directory_lbl = QLabel('directory')
+        self._directory_lbl = label.BaseLabel('directory', parent=self)
         self._directory_lbl.setMinimumWidth(60)
         self._directory_lbl.setMaximumWidth(100)
-        self._directory_edit = QLineEdit()
+        self._directory_edit = lineedit.BaseLineEdit(parent=self)
         self._directory_edit.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
-        self._directory_browse_btn = QPushButton('browse')
+        self._directory_browse_btn = buttons.BaseButton('browse', parent=self)
 
         directory_layout.addWidget(self._directory_lbl)
         directory_layout.addWidget(self._directory_edit)
@@ -564,7 +536,7 @@ class GetDirectoryWidget(base.DirectoryWidget, object):
 
     def set_error(self, flag):
 
-        if tp.is_maya():
+        if dcc.is_maya():
             yes_color = QColor(0, 255, 0, 50)
             no_color = QColor(255, 0, 0, 50)
         else:
@@ -587,7 +559,7 @@ class GetDirectoryWidget(base.DirectoryWidget, object):
             self.set_error(True)
 
         if not text:
-            self._directory_edit.setPalette(QLineEdit().palette())
+            self._directory_edit.setPalette(lineedit.BaseLineEdit().palette())
 
         self.directoryChanged.emit(directory)
 
