@@ -7,9 +7,9 @@ Module that contains classes to create different kind of labels
 
 from __future__ import print_function, division, absolute_import
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
-from Qt.QtGui import *
+from Qt.QtCore import Qt, Signal, Property, QRect, QSize, QPropertyAnimation
+from Qt.QtWidgets import QSizePolicy, QLabel, QLineEdit, QStyleOption
+from Qt.QtGui import QFontMetrics, QTextCursor, QTextDocument, QPainter
 
 from tpDcc.libs.qt.core import qtutils
 from tpDcc.libs.qt.widgets import graphicseffects
@@ -17,6 +17,8 @@ from tpDcc.libs.qt.widgets import graphicseffects
 
 class BaseLabel(QLabel, object):
 
+    clicked = Signal()
+
     class Levels(object):
         H1 = 1
         H2 = 2
@@ -209,6 +211,10 @@ class BaseLabel(QLabel, object):
     #
     #     return super(BaseLabel, self).event(event)
 
+    def mousePressEvent(self, event):
+        self.clicked.emit()
+        super(BaseLabel, self).mousePressEvent(event)
+
     def minimumSizeHint(self):
         """
          Overrides base QObject minimumSizeHint function
@@ -420,14 +426,14 @@ class ClickLabel(QLabel, object):
         super(ClickLabel, self).mousePressEvent(event)
 
 
-class RightElidedLabel(QLabel, object):
+class RightElidedLabel(BaseLabel, object):
     """
     Custom label which supports elide right
     """
 
-    def __init__(self, *args):
-        super(RightElidedLabel, self).__init__(*args)
-        self._text = ''
+    def __init__(self, *args, **kwargs):
+        super(RightElidedLabel, self).__init__(*args, **kwargs)
+        self._text = self.text()
 
     def setText(self, text):
         """
@@ -451,13 +457,13 @@ class RightElidedLabel(QLabel, object):
         super(RightElidedLabel, self).setText(elided)
 
 
-class ElidedLabel(QLabel, object):
+class ElidedLabel(BaseLabel, object):
     """
     This label elides text and adds ellipses if the text does not fit
     properly withing the widget frame
     """
 
-    def __init__(self, parent=None):
+    def __init__(self, text='', parent=None):
         super(ElidedLabel, self).__init__(parent=parent)
 
         self._elide_mode = Qt.ElideRight
@@ -467,6 +473,8 @@ class ElidedLabel(QLabel, object):
 
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Preferred)
 
+        self.setText(text)
+
     def sizeHint(self):
 
         base_size_hint = super(ElidedLabel, self).sizeHint()
