@@ -7,8 +7,8 @@ Module that contains custom extra layout implementations
 
 from __future__ import print_function, division, absolute_import
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
+from Qt.QtCore import Qt, QPoint, QRect, QSize
+from Qt.QtWidgets import QLayout, QHBoxLayout, QVBoxLayout, QGridLayout, QFormLayout, QWidget, QWidgetItem
 
 from tpDcc.libs.qt.core import consts, qtutils
 
