@@ -7,11 +7,14 @@ Module that includes classes to create different types of message boxes
 
 from __future__ import print_function, division, absolute_import
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
+from Qt.QtCore import Qt, QEvent
+from Qt.QtWidgets import QSizePolicy, QFrame, QDialog, QDialogButtonBox
 
-import tpDcc as tp
-from tpDcc.libs.qt.core import animation, qtutils, theme
+from tpDcc import dcc
+from tpDcc.libs.python import python
+from tpDcc.libs.resources.core import theme
+from tpDcc.libs.qt.core import animation, qtutils
+from tpDcc.libs.qt.widgets import layouts, label, checkbox, lineedit
 
 
 def create_message_box(parent, title, text, width=None, height=None, buttons=None, header_pixmap=None,
@@ -50,7 +53,7 @@ def create_message_box(parent, title, text, width=None, height=None, buttons=Non
 
     mb.setStyleSheet(theme_to_apply.stylesheet())
 
-    header_color = header_color or theme_to_apply.accent_color or "rgb(50, 150, 200)"
+    header_color = header_color or theme_to_apply.window_dragger_color or "rgb(50, 150, 225)"
     mb.set_header_color(header_color)
     mb.setWindowTitle(title)
     mb.set_title_text(title)
@@ -76,7 +79,7 @@ def show_message_box(parent, title, text, width=None, height=None, buttons=None,
     :return: MessageBox
     """
 
-    if isinstance(enable_dont_show_checkbox, (str, basestring)):
+    if python.is_string(enable_dont_show_checkbox):
         enable_dont_show_checkbox = enable_dont_show_checkbox == 'true'
 
     clicked_btn = None
@@ -195,7 +198,7 @@ class MessageBox(QDialog, object):
         :return: QDialogButtonBox.StandardButton
         """
 
-        buttons = buttons or QDialogButtonBox.Ok
+        buttons = buttons or QDialogButtonBox.Ok | QDialogButtonBox.Cancel
         clicked_btn = show_message_box(parent=parent, title=title, text=text, width=width, height=height,
                                        buttons=buttons, header_pixmap=header_pixmap, header_color=header_color)
         return clicked_btn
@@ -203,9 +206,7 @@ class MessageBox(QDialog, object):
     def __init__(self, name='messageBox', width=None, height=None, enable_input_edit=False,
                  enable_dont_show_checkbox=False, parent=None):
 
-        super(MessageBox, self).__init__(
-            parent=parent
-        )
+        super(MessageBox, self).__init__(parent=parent)
 
         self._frame = None
         self._animation = None
@@ -221,16 +222,16 @@ class MessageBox(QDialog, object):
         # self.setStyleSheet('background-color: rgb(68, 68, 68, 255);')
 
         parent = self.parent()
-        if parent and parent != tp.Dcc.get_main_window():
+        self._frame = None
+        if parent and parent != dcc.get_main_window():
             parent.installEventFilter(self)
             self._frame = QFrame(parent)
+            self._frame.setStyleSheet('background-color: rgba(25, 25, 25, 150);')
             self._frame.setObjectName('messageBoxFrame')
             self._frame.show()
             self.setParent(self._frame)
 
-        self.main_layout = QVBoxLayout()
-        self.main_layout.setContentsMargins(0, 0, 0, 0)
-        self.main_layout.setSpacing(0)
+        self.main_layout = layouts.VerticalLayout(spacing=0, margins=(0, 0, 0, 0))
         self.setLayout(self.main_layout)
 
         self._header = QFrame(self)
@@ -238,7 +239,7 @@ class MessageBox(QDialog, object):
         self._header.setObjectName('messageBoxHeaderFrame')
         self._header.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Fixed)
 
-        self._icon = QLabel(self._header)
+        self._icon = label.BaseLabel(parent=self._header)
         self._icon.hide()
         self._icon.setFixedHeight(32)
         self._icon.setFixedHeight(32)
@@ -246,23 +247,21 @@ class MessageBox(QDialog, object):
         self._icon.setAlignment(Qt.AlignTop)
         self._icon.setSizePolicy(QSizePolicy.Preferred, QSizePolicy.Preferred)
 
-        self._title = QLabel(self._header)
+        self._title = label.BaseLabel(parent=self._header)
         self._title.setObjectName('messageBoxHeaderLabel')
         self._title.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
 
-        hlayout = QHBoxLayout(self._header)
-        hlayout.setContentsMargins(15, 7, 15, 10)
-        hlayout.setSpacing(10)
+        hlayout = layouts.HorizontalLayout(spacing=10, margins=(15, 7, 15, 10))
         hlayout.addWidget(self._icon)
         hlayout.addWidget(self._title)
         self._header.setLayout(hlayout)
 
-        body_layout = QVBoxLayout(self)
+        body_layout = layouts.VerticalLayout()
         self._body = QFrame(self)
         self._body.setObjectName('messageBoxBody')
         self._body.setLayout(body_layout)
 
-        self._message = QLabel(self._body)
+        self._message = label.BaseLabel(parent=self._body)
         self._message.setWordWrap(True)
         self._message.setMinimumHeight(15)
         self._message.setAlignment(Qt.AlignLeft)
@@ -272,7 +271,7 @@ class MessageBox(QDialog, object):
         body_layout.setContentsMargins(15, 15, 15, 15)
 
         if enable_input_edit:
-            self._input_edit = QLineEdit(self._body)
+            self._input_edit = lineedit.BaseLineEdit(parent=self._body)
             self._input_edit.setObjectName('messageBoxInputEdit')
             self._input_edit.setMinimumHeight(32)
             self._input_edit.setFocus()
@@ -282,7 +281,7 @@ class MessageBox(QDialog, object):
 
         if enable_dont_show_checkbox:
             msg = 'Do not show this message again'
-            self._dont_show_checkbox = QCheckBox(msg, self._body)
+            self._dont_show_checkbox = checkbox.BaseCheckBox(msg, parent=self._body)
             body_layout.addStretch(10)
             body_layout.addWidget(self._dont_show_checkbox)
             body_layout.addStretch(2)
@@ -298,17 +297,17 @@ class MessageBox(QDialog, object):
 
         self.updateGeometry()
 
-    # def eventFilter(self, object, event):
-    #     """
-    #     Overrides base QDialog eventFilter function
-    #     Updates the geometry when the parnet widget changes size
-    #     :param object: QWidget
-    #     :param event: QEvent
-    #     """
-    #
-    #     if event.type() == QEvent.Resize:
-    #         self.updateGeometry()
-    #     return super(MessageBox, self).eventFilter(object, event)
+    def eventFilter(self, object, event):
+        """
+        Overrides base QDialog eventFilter function
+        Updates the geometry when the parnet widget changes size
+        :param object: QWidget
+        :param event: QEvent
+        """
+
+        if event.type() == QEvent.Resize:
+            self.updateGeometry()
+        return super(MessageBox, self).eventFilter(object, event)
 
     def showEvent(self, event):
         """
@@ -320,6 +319,10 @@ class MessageBox(QDialog, object):
         self.updateGeometry()
         self._fade_in()
 
+    def keyPressEvent(self, event):
+        if event.key() != Qt.Key_Escape:
+            super(MessageBox, self).keyPressEvent(event)
+
     def updateGeometry(self):
         """
         Overrides base QDialog updateGeometry function
@@ -401,6 +404,8 @@ class MessageBox(QDialog, object):
         """
 
         self._input_edit.setText(text)
+        if text:
+            self._input_edit.selectAll()
 
     def add_button(self, *args):
         """
