@@ -7,17 +7,16 @@ Module that contains custom Qt spinner widgets
 
 from __future__ import print_function, division, absolute_import
 
-from functools import partial
+from Qt.QtCore import Qt, Signal, Property, QPoint, QRect
+from Qt.QtWidgets import QSizePolicy, QFrame, QSpinBox, QDoubleSpinBox
+from Qt.QtGui import QColor, QPainter, QDoubleValidator
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
-from Qt.QtGui import *
-
-from tpDcc.libs.qt.core import base, mixin, theme
-from tpDcc.libs.qt.widgets import lineedit, buttons, label
+from tpDcc.libs.resources.core import theme
+from tpDcc.libs.qt.core import base, contexts as qt_contexts
+from tpDcc.libs.qt.widgets import layouts, lineedit, buttons, label
 
 
-@mixin.theme_mixin
+@theme.mixin
 # @mixin.cursor_mixin
 class BaseSpinBox(QSpinBox, object):
     def __init__(self, parent=None):
@@ -103,8 +102,8 @@ class BaseSpinBox(QSpinBox, object):
         return self
 
 
-@mixin.theme_mixin
-@mixin.cursor_mixin
+@theme.mixin
+# @mixin.cursor_mixin
 class BaseDoubleSpinBox(QDoubleSpinBox, object):
     def __init__(self, parent=None):
         super(BaseDoubleSpinBox, self).__init__(parent=parent)
@@ -197,9 +196,8 @@ class BaseNumberWidget(base.BaseWidget, object):
         super(BaseNumberWidget, self).__init__(parent)
 
     def get_main_layout(self):
-        main_layout = QHBoxLayout()
-        main_layout.setContentsMargins(0, 0, 0, 0)
-        main_layout.setSpacing(0)
+        main_layout = layouts.HorizontalLayout(spacing=0, margins=(0, 0, 0, 0))
+
         return main_layout
 
     def ui(self):
@@ -256,6 +254,9 @@ class BaseNumberWidget(base.BaseWidget, object):
     def set_label_text(self, new_text):
         self._number_label.setText(new_text)
 
+    def setDecimals(self, value):
+        self._number_widget.setDecimals(value)
+
     def set_value_label(self, new_value):
         self._value_label.show()
         self._value_label.setText(str(new_value))
@@ -324,7 +325,7 @@ class DragDoubleSpinBoxLine(lineedit.BaseLineEdit, object):
 
     valueChanged = Signal(float)
 
-    def __init__(self, start=0.0, max=10, min=-10, positive=False, parent=None):
+    def __init__(self, start=0.0, max=10, min=-10, positive=False, decimals=4, parent=None):
         super(DragDoubleSpinBoxLine, self).__init__(parent=parent)
 
         self._click = False
@@ -332,6 +333,7 @@ class DragDoubleSpinBoxLine(lineedit.BaseLineEdit, object):
         self._mouse_position = QPoint(0, 0)
         self._min = 0.01 if positive else min
         self._max = max
+        self._decimals = decimals or 3
         self._sup = positive
         self.setText(str(start))
 
@@ -340,6 +342,28 @@ class DragDoubleSpinBoxLine(lineedit.BaseLineEdit, object):
         theme = self.theme()
         self._color = theme.accent_color_5 or QColor(0, 255, 0)
 
+        self.textChanged.connect(self._on_text_changed)
+
+    def _on_text_changed(self, text):
+
+        cursor_pos = self.cursorPosition()
+
+        value = round(float(text), self._decimals)
+        if value > self._max:
+            value = self._max
+        elif value < self._min:
+            value = self._min
+
+        value = str(value)
+
+        self.setText(value)
+
+        self.setCursorPosition(cursor_pos)
+
+    @property
+    def default(self):
+        return self._default
+
     def mousePressEvent(self, event):
         if event.button() == Qt.MiddleButton:
             self._click = True
@@ -357,7 +381,7 @@ class DragDoubleSpinBoxLine(lineedit.BaseLineEdit, object):
             delta = event.x() - self._mouse_position.x()
             v = float(self.text()) + delta / 100.0
             v = max(self._min, min(self._max, v))
-            self.setText(str(v))
+            self.setText(str(round(v, self._decimals)))
             self._mouse_position = event.pos()
             self.valueChanged.emit(v)
 
@@ -386,12 +410,34 @@ class DragDoubleSpinBoxLine(lineedit.BaseLineEdit, object):
     def get_validator(self):
         return QDoubleValidator()
 
+    def set_default(self, default):
+        self._default = default
+
+    def set_minimum(self, minimum_value):
+        self._min = minimum_value
+        if self.value() < self._min:
+            self.setValue(self._min)
+        self.update()
+
+    def set_maximum(self, maximum_value):
+        self._max = maximum_value
+        if self.value() > self._max:
+            self.setValue(self._max)
+        self.update()
+
     def value(self):
         try:
             return float(self.text())
         except Exception:
             return 0.0
 
+    def setText(self, text):
+        super(DragDoubleSpinBoxLine, self).setText(text)
+        self.valueChanged.emit(self.value())
+
+    def setDecimals(self, value):
+        self._decimals = int(value)
+
     # NOTE: Here I'm breaking naming nomenclature on purpose. Doing this we follow nomenclature of Qt SpinBoxes
     def setValue(self, new_value):
         self.setText(str(new_value))
@@ -400,6 +446,77 @@ class DragDoubleSpinBoxLine(lineedit.BaseLineEdit, object):
         self.setValidator(self.get_validator())
 
 
+class DoubleSpinBoxAxis(base.BaseWidget, object):
+
+    textChanged = Signal(str)
+    valueChanged = Signal(float)
+
+    def __init__(self, axis, start=0.0, max=10, min=-10, positive=False, parent=None):
+        self._axis = axis
+        self._start = start
+        self._max = max
+        self._min = min
+        if positive:
+            self._min = 0
+        super(DoubleSpinBoxAxis, self).__init__(parent=parent)
+
+    def get_main_layout(self):
+        main_layout = layouts.HorizontalLayout(spacing=0, margins=(0, 0, 0, 0))
+
+        return main_layout
+
+    def ui(self):
+        super(DoubleSpinBoxAxis, self).ui()
+
+        axis_widget = QFrame(parent=self)
+        axis_widget.setFrameStyle(QFrame.StyledPanel | QFrame.Raised)
+        axis_layout = layouts.HorizontalLayout(spacing=0, margins=(0, 0, 0, 0))
+        axis_widget.setLayout(axis_layout)
+        self._axis_btn = buttons.get_axis_button(axis_type=self._axis, parent=self)
+        self._line = BaseDoubleSpinBox(parent=self)
+        self._line.setRange(self._min, self._max)
+        self._line.setValue(self._start)
+        axis_layout.addWidget(self._axis_btn)
+        axis_layout.addWidget(self._line)
+
+        self.main_layout.addWidget(axis_widget)
+
+    def setup_signals(self):
+        self._line.valueChanged.connect(self.valueChanged.emit)
+
+    def _get_value(self):
+        return self.value()
+
+    def _set_value(self, value):
+        with qt_contexts.block_signals(self, children=True):
+            self.setValue(value)
+
+    floatValue = Property(float, _get_value, _set_value)
+
+    def value(self):
+        return self._line.value()
+
+    def setValue(self, new_value):
+        self._line.setValue(new_value)
+
+    def setDecimals(self, value):
+        self._line.setDecimals(value)
+
+    def setRange(self, min_range, max_range):
+        self._min = min_range
+        self._max = max_range
+        self._line.setMinimum(min_range)
+        self._line.setMaximum(max_range)
+
+    def set_minimum(self, minimum_value):
+        self._min = minimum_value
+        self._line.setMinimum(self._min)
+
+    def set_maximum(self, maximum_value):
+        self._max = maximum_value
+        self._line.setMaximum(self._max)
+
+
 class DragDoubleSpinBoxLineAxis(base.BaseWidget, object):
 
     textChanged = Signal(str)
@@ -415,9 +532,7 @@ class DragDoubleSpinBoxLineAxis(base.BaseWidget, object):
         super(DragDoubleSpinBoxLineAxis, self).__init__(parent=parent)
 
     def get_main_layout(self):
-        main_layout = QHBoxLayout()
-        main_layout.setContentsMargins(0, 0, 0, 0)
-        main_layout.setSpacing(0)
+        main_layout = layouts.HorizontalLayout(spacing=0, margins=(0, 0, 0, 0))
 
         return main_layout
 
@@ -426,9 +541,7 @@ class DragDoubleSpinBoxLineAxis(base.BaseWidget, object):
 
         axis_widget = QFrame()
         axis_widget.setFrameStyle(QFrame.StyledPanel | QFrame.Raised)
-        axis_layout = QHBoxLayout()
-        axis_layout.setContentsMargins(0, 0, 0, 0)
-        axis_layout.setSpacing(0)
+        axis_layout = layouts.HorizontalLayout(spacing=0, margins=(0, 0, 0, 0))
         axis_widget.setLayout(axis_layout)
         self._axis_btn = buttons.get_axis_button(axis_type=self._axis, parent=self)
         self._line = DragDoubleSpinBoxLine(
@@ -443,12 +556,42 @@ class DragDoubleSpinBoxLineAxis(base.BaseWidget, object):
         self.main_layout.addWidget(axis_widget)
 
     def setup_signals(self):
-        self._reset_btn.clicked.connect(partial(self._line.setValue, self._start))
+        self._reset_btn.clicked.connect(self._on_reset)
         self._line.valueChanged.connect(self.valueChanged.emit)
         self._line.textChanged.connect(self.textChanged.emit)
 
+    def _get_value(self):
+        return self.value()
+
+    def _set_value(self, value):
+        with qt_contexts.block_signals(self, children=True):
+            self.setValue(value)
+
+    floatValue = Property(float, _get_value, _set_value)
+
     def value(self):
         return self._line.value()
 
     def setValue(self, new_value):
         self._line.setValue(new_value)
+
+    def setDecimals(self, value):
+        self._line.setDecimals(value)
+
+    def setRange(self, min_range, max_range):
+        self._line.set_minimum(min_range)
+        self._line.set_maximum(max_range)
+
+    def set_default(self, default):
+        self._line.set_default(default)
+
+    def set_minimum(self, minimum_value):
+        self._min = minimum_value
+        self._line.set_minimum(self._min)
+
+    def set_maximum(self, maximum_value):
+        self._max = maximum_value
+        self._line.set_maximum(self._max)
+
+    def _on_reset(self):
+        self._line.setValue(str(self._line.default))
