@@ -7,10 +7,10 @@ Module that contains custom Qt stack widgets
 
 from __future__ import print_function, division, absolute_import
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
+from Qt.QtCore import Qt, Signal, QPoint, QEasingCurve, QPropertyAnimation, QParallelAnimationGroup
+from Qt.QtWidgets import QFrame, QStackedWidget
 
-import tpDcc
+from tpDcc.managers import resources
 from tpDcc.libs.qt.core import consts, qtutils, base, dpi, mixin
 from tpDcc.libs.qt.widgets import layouts, buttons, lineedit
 
@@ -122,13 +122,13 @@ class SlidingStackedWidget(QStackedWidget, object):
         self.widget(next).raise_()
         self._current_widget = self.widget(next)
 
-        anim_now = QPropertyAnimation(self.widget(now), 'pos')
+        anim_now = QPropertyAnimation(self.widget(now), b'pos')
         anim_now.setDuration(self._speed)
         anim_now.setStartValue(pnow)
         anim_now.setEndValue(QPoint(pnow.x() - offset_x, pnow.y() - offset_y))
         anim_now.setEasingCurve(self._animation_type)
 
-        anim_next = QPropertyAnimation(self.widget(next), 'pos')
+        anim_next = QPropertyAnimation(self.widget(next), b'pos')
         anim_next.setDuration(self._speed)
         anim_next.setStartValue(QPoint(offset_x + pnext.x(), offset_y + pnext.y()))
         anim_next.setEndValue(pnext)
@@ -221,9 +221,10 @@ class StackItem(QFrame, object):
     def ui(self):
         # theme = tpDcc.ToolsMgr().get_tool_theme('tpDcc-tools-hub')
         # border_width = qtutils.dpi_scale_divide(theme.STACK_BORDER_WIDTH)
-        border_width = qtutils.dpi_scale_divide(1)
-        self.main_layout = layouts.VerticalLayout(
-            margins=(border_width, border_width, border_width, border_width), spacing=0)
+        margin = qtutils.dpi_scale_divide(1)
+        self.main_layout = layouts.VerticalLayout(margins=(margin, margin, margin, margin), spacing=0)
+        # self.main_layout = layouts.VerticalLayout(margins=(0, 0, 0, 0), spacing=0)
+
         self.setLayout(self.main_layout)
 
         if not self._title_frame:
@@ -235,10 +236,9 @@ class StackItem(QFrame, object):
             self._title_frame.item_icon_button.hide()
 
         self._widget_hider = StackHiderWidget(parent=self)
-        self._contents_layout = layouts.VerticalLayout(spacing=0)
+        self._contents_layout = self._widget_hider.main_layout
         self._contents_layout.setContentsMargins(*self._contents_margins)
         self._contents_layout.setSpacing(self._contents_spacing)
-        self._widget_hider.setLayout(self._contents_layout)
         self._widget_hider.setContentsMargins(0, 0, 0, 0)
         self._widget_hider.setHidden(self._collapsed)
         self._widget_hider.setObjectName('stackbody')
@@ -451,8 +451,8 @@ class StackTitleFrame(QFrame, dpi.DPIScaling):
         self._collapsed = collapsed
         self._item_icon_size = item_icon_size
 
-        self._collapsed_icon = tpDcc.ResourcesMgr().icon('sort_closed')
-        self._expand_icon = tpDcc.ResourcesMgr().icon('sort_down')
+        self._collapsed_icon = resources.icon('sort_closed')
+        self._expand_icon = resources.icon('sort_down')
 
         self.setObjectName('title')
 
@@ -500,12 +500,12 @@ class StackTitleFrame(QFrame, dpi.DPIScaling):
 
     def ui(self):
 
-        item_icon = tpDcc.ResourcesMgr().icon(self._item_icon)
+        item_icon = resources.icon(self._item_icon)
         if item_icon.isNull():
-            item_icon = tpDcc.ResourcesMgr().icon('tpdcc')
-        delete_icon = tpDcc.ResourcesMgr().icon('delete')
-        shift_up_icon = tpDcc.ResourcesMgr().icon('arrow_up')
-        shift_down_icon = tpDcc.ResourcesMgr().icon('arrow_down')
+            item_icon = resources.icon('tpdcc')
+        delete_icon = resources.icon('delete')
+        shift_up_icon = resources.icon('arrow_up')
+        shift_down_icon = resources.icon('arrow_down')
 
         self.setContentsMargins(*qtutils.margins_dpi_scale(0, 0, 0, 0))
         self._extras_layout = layouts.HorizontalLayout(margins=(0, 0, 0, 0), spacing=0)
@@ -543,7 +543,7 @@ class StackTitleFrame(QFrame, dpi.DPIScaling):
         self._expand_toggle_btn.set_icon(self._expand_icon, colors=(192, 192, 192), size=icon_size)
 
         self._horizontal_layout.addWidget(self._item_icon_btn)
-        self._horizontal_layout.addItem(QSpacerItem(10, 10, QSizePolicy.Expanding, QSizePolicy.Minimum))
+        self._horizontal_layout.addStretch()
         self._horizontal_layout.addWidget(self._line_edit)
         self._horizontal_layout.addLayout(self._extras_layout)
         self._horizontal_layout.addWidget(self._shift_up_btn)
