@@ -7,16 +7,16 @@ Module that contains custom Qt tree widgets
 
 from __future__ import print_function, division, absolute_import
 
-import string
+from Qt.QtCore import Qt, Signal, QRect, QSize, QModelIndex
+from Qt.QtWidgets import QApplication, QSizePolicy, QTreeWidget, QTreeWidgetItem, QAbstractItemView, QStyleOption
+from Qt.QtWidgets import QWhatsThis
+from Qt.QtGui import QColor, QPalette, QPen, QBrush, QPainter
 
-from Qt.QtCore import *
-from Qt.QtWidgets import *
-from Qt.QtGui import *
-
-import tpDcc as tp
+from tpDcc import dcc
+from tpDcc.managers import resources
 from tpDcc.libs.python import path, fileio, folder
 from tpDcc.libs.qt.core import base
-from tpDcc.libs.qt.widgets import buttons, search, lineedit
+from tpDcc.libs.qt.widgets import layouts, buttons, search, lineedit
 
 
 class TreeWidget(QTreeWidget, object):
@@ -36,16 +36,17 @@ class TreeWidget(QTreeWidget, object):
         self._current_item = None
         self._last_item = None
         self._drop_indicator_rect = QRect()
+        self._drop_indicator_position = None
+        self._name_filter = None
 
         self.setIndentation(25)
         self.setExpandsOnDoubleClick(False)
-
-        if tp.Dcc.get_name() == tp.Dccs.Maya:
-            self.setAlternatingRowColors(tp.Dcc.get_version() < 2016)
-
         self.setSortingEnabled(True)
         self.sortByColumn(0, Qt.AscendingOrder)
-        if not tp.is_maya() and not not tp.is_nuke():
+
+        if dcc.is_maya():
+            self.setAlternatingRowColors(dcc.get_version() < 2016)
+        if not dcc.is_maya() and not not dcc.is_nuke():
             palette = QPalette()
             palette.setColor(palette.Highlight, Qt.gray)
             self.setPalette(palette)
@@ -194,12 +195,14 @@ class TreeWidget(QTreeWidget, object):
         :param filter_text: str, text used to filter tree items
         """
 
+        self._name_filter = filter_text.strip(' ')
+
         self.unhide_items()
 
         for i in range(self.topLevelItemCount()):
             item = self.topLevelItem(i)
             text = str(item.text(self._title_text_index))
-            filter_text = str(filter_text)
+            filter_text = str(filter_text).strip(' ')
 
             # If the filter text is not found on the item text, we hide the item
             if text.find(filter_text) == -1:
@@ -247,7 +250,7 @@ class TreeWidget(QTreeWidget, object):
 
         names.reverse()
 
-        item_path_str = string.join(names, '/')
+        item_path_str = '/'.join(names)
 
         return item_path_str
 
@@ -443,7 +446,7 @@ class TreeWidget(QTreeWidget, object):
             rect = opt.rect
 
             color = Qt.black
-            if tp.is_maya():
+            if dcc.is_maya():
                 color = Qt.white
 
             brush = QBrush(QColor(color))
@@ -730,17 +733,13 @@ class FilterTreeWidget(base.DirectoryWidget, object):
     # ============================================================================================================
 
     def get_main_layout(self):
-        main_layout = QHBoxLayout()
-        main_layout.setContentsMargins(0, 0, 0, 0)
-        main_layout.setSpacing(0)
+        main_layout = layouts.HorizontalLayout(spacing=0, margins=(0, 0, 0, 0))
         return main_layout
 
     def ui(self):
         super(FilterTreeWidget, self).ui()
 
-        texts_layout = QVBoxLayout()
-        texts_layout.setContentsMargins(0, 0, 0, 0)
-        texts_layout.setSpacing(2)
+        texts_layout = layouts.VerticalLayout(spacing=2, margins=(0, 0, 0, 0))
         self._filter_names = search.SearchFindWidget()
         self._filter_names.set_placeholder_text('Filter Names')
         self._sub_path_filter = lineedit.BaseLineEdit()
@@ -840,7 +839,7 @@ class FilterTreeWidget(base.DirectoryWidget, object):
         """
 
         if flag:
-            if tp.is_maya():
+            if dcc.is_maya():
                 self._sub_path_filter.setStyleSheet('background-color: rgb(255, 100, 100);')
             else:
                 self._sub_path_filter.setStyleSheet('background-color: rgb(255, 150, 150);')
@@ -902,7 +901,7 @@ class FileTreeWidget(TreeWidget, object):
 
     HEADER_LABELS = ['Name', 'Size MB', 'Time']
     NEW_ITEM_NAME = 'new_file'
-    NEW_ITEM_WIDGET = QTreeWidgetItem
+    ITEM_WIDGET = QTreeWidgetItem
     EXCLUDE_EXTENSIONS = list()
 
     def __init__(self, parent=None):
@@ -911,6 +910,14 @@ class FileTreeWidget(TreeWidget, object):
 
         self.setHeaderLabels(self.HEADER_LABELS)
 
+    # ============================================================================================================
+    # PROPERTIES
+    # ============================================================================================================
+
+    @property
+    def directory(self):
+        return self._directory
+
     # ============================================================================================================
     # OVERRIDES
     # ============================================================================================================
@@ -965,7 +972,7 @@ class FileTreeWidget(TreeWidget, object):
         if found:
             item = found
         else:
-            item = self.ITEM_WIDGET()
+            item = self.create_item_widget(file_name)
 
         # Constrain item size if necessary
         size = self.ITEM_WIDGET_SIZE
@@ -1052,7 +1059,7 @@ class FileTreeWidget(TreeWidget, object):
     # BASE
     # ============================================================================================================
 
-    def set_directory(self, directory, refresh=True):
+    def set_directory(self, directory, refresh=True, name_filter=None):
         """
         Sets the directory used by this QTreeWidget
         :param directory: str, directory
@@ -1060,6 +1067,7 @@ class FileTreeWidget(TreeWidget, object):
         """
 
         self._directory = directory
+        self._name_filter = name_filter
         if refresh:
             self.refresh()
 
@@ -1073,6 +1081,14 @@ class FileTreeWidget(TreeWidget, object):
         path_str = self.get_tree_item_path_string(tree_item)
         return path.join_path(self._directory, path_str)
 
+    def create_item_widget(self, file_name):
+        """
+        Creates a new item widget
+        :return: variant
+        """
+
+        return self.ITEM_WIDGET()
+
     def create_item(self, name=None):
         """
         Creates a new item (folder) inside the selected item
@@ -1199,24 +1215,20 @@ class EditFileTreeWidget(base.DirectoryWidget, object):
 
         self.setSizePolicy(QSizePolicy.Minimum, QSizePolicy.Minimum)
 
-        self._tree_widget = self.TREE_WIDGET()
+        self._tree_widget = self.TREE_WIDGET(parent=self)
 
-        self._manager_widget = self.MANAGER_WIDGET()
+        self._manager_widget = self.MANAGER_WIDGET(parent=self)
         self._manager_widget.set_tree_widget(self._tree_widget)
 
-        self._filter_widget = self.FILTER_WIDGET()
+        self._filter_widget = self.FILTER_WIDGET(parent=self)
         self._filter_widget.set_tree_widget(self._tree_widget)
         self._filter_widget.set_directory(self._directory)
-        drag_reorder_icon = tp.ResourcesMgr().icon('drag_reorder')
-        edit_mode_layout = QVBoxLayout()
+        drag_reorder_icon = resources.icon('drag_reorder')
+        edit_mode_layout = layouts.VerticalLayout(spacing=0, margins=(0, 0, 0, 0))
         edit_mode_layout.setAlignment(Qt.AlignBottom)
-        edit_mode_layout.setContentsMargins(0, 0, 0, 0)
-        edit_mode_layout.setSpacing(0)
-        self._edit_mode_btn = buttons.IconButton(
-            icon=drag_reorder_icon, icon_padding=2, button_style=buttons.ButtonStyles.FlatStyle)
+        self._edit_mode_btn = buttons.BaseButton(parent=self)
+        self._edit_mode_btn.setIcon(drag_reorder_icon)
         self._edit_mode_btn.setCheckable(True)
-        self._edit_mode_btn.setMaximumHeight(20)
-        self._edit_mode_btn.setMaximumWidth(40)
         edit_mode_layout.addWidget(self._edit_mode_btn)
         self._filter_widget.main_layout.addLayout(edit_mode_layout)
 
@@ -1353,6 +1365,9 @@ class EditFileTreeWidget(base.DirectoryWidget, object):
             if not checked_children:
                 children = list()
                 continue
+            children = new_children
+            if checked_children:
+                levels.append(checked_children)
 
         tree_item.setExpanded(expand_state)
         levels.reverse()
@@ -1403,7 +1418,7 @@ class TreeWidgetItem(QTreeWidgetItem, object):
     def __init__(self, parent=None):
         self._widget = self._get_widget()
         if self._widget:
-            self._widget.item = self
+            self._widget.item_view = self
         self.column = self._get_column()
         super(TreeWidgetItem, self).__init__(parent)
 
